/* $Id$ */
/* File: tables.c */

/* Purpose: Angband Tables */

/*
 * Copyright (c) 1989 James E. Wilson, Robert A. Koeneke
 *
 * This software may be copied and distributed for educational, research, and
 * not for profit purposes provided that this copyright and statement are
 * included in all such copies.
 */

#include "angband.h"


/*
 * XXX XXX Important notice:
 *
 * adj_*_* arrays are frequently used beyond the original purpose
 * (yeah, truly bad hack), so changing them may cause various
 * unexpected side-effects.
 * grep the array name first and do it deliberately!
 */


/*
 * Global array for looping through the "keypad directions"
 */
s16b ddd[9] =
{ 2, 8, 6, 4, 3, 1, 9, 7, 5 };

/*
 * Global arrays for converting "keypad direction" into offsets
 */
s16b ddx[10] =
{ 0, -1, 0, 1, -1, 0, 1, -1, 0, 1 };

s16b ddy[10] =
{ 0, 1, 1, 1, 0, 0, 0, -1, -1, -1 };

/*
 * Global arrays for optimizing "ddx[ddd[i]]" and "ddy[ddd[i]]"
 */
s16b ddx_ddd[9] =
{ 0, 0, 1, -1, 1, -1, 1, -1, 0 };

s16b ddy_ddd[9] =
{ 1, -1, 0, 0, 1, 1, -1, -1, 0 };


/* extra stuff for place_rubble() -  C. Blue */
/* Global arrays for cycling through directions, starting at bottom left, clockwise */
s16b ddx_cyc[8] =
{ -1, 0, 1, 1, 1, 0, -1, -1};
s16b ddy_cyc[8] =
{ -1, -1, -1, 0, 1, 1, 1, 0};
/* and for inverting directions of above array ((x+4)%8) */
s16b ddi_cyc[8] =
{ 4, 5, 6, 7, 0, 1, 2, 3};


/*
 * Global array for converting numbers to uppercase hecidecimal digit
 * This array can also be used to convert a number to an octal digit
 */
char hexsym[16] =
{
	'0', '1', '2', '3', '4', '5', '6', '7',
	'8', '9', 'A', 'B', 'C', 'D', 'E', 'F'
};


/* The following tables are also used by the client and hence in src/common/tables.c:
    adj_mag_fail[]
    adj_mag_stat[]
    adj_int_pow[]
*/


/*
 * Stat Table (INT/WIS) -- Number of half-spells per level
 */
byte adj_mag_study[] =
{
	0	/* 3 */,
	0	/* 4 */,
	0	/* 5 */,
	0	/* 6 */,
	0	/* 7 */,
	1	/* 8 */,
	1	/* 9 */,
	1	/* 10 */,
	1	/* 11 */,
	2	/* 12 */,
	2	/* 13 */,
	2	/* 14 */,
	2	/* 15 */,
	2	/* 16 */,
	2	/* 17 */,
	2	/* 18/00-18/09 */,
	2	/* 18/10-18/19 */,
	2	/* 18/20-18/29 */,
	2	/* 18/30-18/39 */,
	2	/* 18/40-18/49 */,
	3	/* 18/50-18/59 */,
	3	/* 18/60-18/69 */,
	3	/* 18/70-18/79 */,
	3	/* 18/80-18/89 */,
	3	/* 18/90-18/99 */,
	4	/* 18/100-18/109 */,
	4	/* 18/110-18/119 */,
	4	/* 18/120-18/129 */,
	4	/* 18/130-18/139 */,
	4	/* 18/140-18/149 */,
	4	/* 18/150-18/159 */,
	5	/* 18/160-18/169 */,
	5	/* 18/170-18/179 */,
	5	/* 18/180-18/189 */,
	5	/* 18/190-18/199 */,
	5	/* 18/200-18/209 */,
	5	/* 18/210-18/219 */,
	5	/* 18/220+ */
};


/*
 * Stat Table (INT/WIS) -- extra half-mana-points per level
 */
byte adj_mag_mana[] =
{
	0	/* 3 */,
	0	/* 4 */,
	0	/* 5 */,
	0	/* 6 */,
	0	/* 7 */,
	1	/* 8 */,
	2	/* 9 */,
	2	/* 10 */,
	2	/* 11 */,
	2	/* 12 */,
	2	/* 13 */,
	2	/* 14 */,
	2	/* 15 */,
	2	/* 16 */,
	2	/* 17 */,
	3	/* 18/00-18/09 */,
	3	/* 18/10-18/19 */,
	3	/* 18/20-18/29 */,
	3	/* 18/30-18/39 */,
	3	/* 18/40-18/49 */,
	4	/* 18/50-18/59 */,
	4	/* 18/60-18/69 */,
	5	/* 18/70-18/79 */,
	6	/* 18/80-18/89 */,
	7	/* 18/90-18/99 */,
	8	/* 18/100-18/109 */,
	9	/* 18/110-18/119 */,
	10	/* 18/120-18/129 */,
	11	/* 18/130-18/139 */,
	12	/* 18/140-18/149 */,
	13	/* 18/150-18/159 */,
	13	/* 18/160-18/169 */,
	14	/* 18/170-18/179 */,
	14	/* 18/180-18/189 */,
	15	/* 18/190-18/199 */,
	15	/* 18/200-18/209 */,
	15	/* 18/210-18/219 */,
	16	/* 18/220+ */
};


/*
 * Stat Table (CHR) -- payment percentages
 */
byte adj_chr_gold[] =
{
	130	/* 3 */,
	125	/* 4 */,
	122	/* 5 */,
	120	/* 6 */,
	118	/* 7 */,
	116	/* 8 */,
	114	/* 9 */,
	112	/* 10 */,
	110	/* 11 */,
	108	/* 12 */,
	106	/* 13 */,
	104	/* 14 */,
	103	/* 15 */,
	102	/* 16 */,
	101	/* 17 */,
	100	/* 18/00-18/09 */,
	99	/* 18/10-18/19 */,
	98	/* 18/20-18/29 */,
	97	/* 18/30-18/39 */,
	96	/* 18/40-18/49 */,
	95	/* 18/50-18/59 */,
	94	/* 18/60-18/69 */,
	93	/* 18/70-18/79 */,
	92	/* 18/80-18/89 */,
	91	/* 18/90-18/99 */,
	90	/* 18/100-18/109 */,
	89	/* 18/110-18/119 */,
	88	/* 18/120-18/129 */,
	87	/* 18/130-18/139 */,
	86	/* 18/140-18/149 */,
	85	/* 18/150-18/159 */,
	84	/* 18/160-18/169 */,
	84	/* 18/170-18/179 */,
	83	/* 18/180-18/189 */,
	83	/* 18/190-18/199 */,
	82	/* 18/200-18/209 */,
	81	/* 18/210-18/219 */,
	80	/* 18/220+ */
};


/*
 * Stat Table (INT) -- Magic devices
 */
byte adj_int_dev[] =
{
	0	/* 3 */,
	0	/* 4 */,
	0	/* 5 */,
	0	/* 6 */,
	0	/* 7 */,
	1	/* 8 */,
	1	/* 9 */,
	1	/* 10 */,
	1	/* 11 */,
	1	/* 12 */,
	1	/* 13 */,
	1	/* 14 */,
	2	/* 15 */,
	2	/* 16 */,
	2	/* 17 */,
	3	/* 18/00-18/09 */,
	3	/* 18/10-18/19 */,
	4	/* 18/20-18/29 */,
	4	/* 18/30-18/39 */,
	5	/* 18/40-18/49 */,
	5	/* 18/50-18/59 */,
	6	/* 18/60-18/69 */,
	6	/* 18/70-18/79 */,
	7	/* 18/80-18/89 */,
	7	/* 18/90-18/99 */,
	8	/* 18/100-18/109 */,
	9	/* 18/110-18/119 */,
	10	/* 18/120-18/129 */,
	11	/* 18/130-18/139 */,
	12	/* 18/140-18/149 */,
	13	/* 18/150-18/159 */,
	14	/* 18/160-18/169 */,
	15	/* 18/170-18/179 */,
	16	/* 18/180-18/189 */,
	17	/* 18/190-18/199 */,
	18	/* 18/200-18/209 */,
	19	/* 18/210-18/219 */,
	20	/* 18/220+ */
};


/*
 * Stat Table (WIS) -- Saving throw
 */
byte adj_wis_sav[] =
{
	0	/* 3 */,
	0	/* 4 */,
	0	/* 5 */,
	0	/* 6 */,
	0	/* 7 */,
	1	/* 8 */,
	1	/* 9 */,
	1	/* 10 */,
	1	/* 11 */,
	1	/* 12 */,
	1	/* 13 */,
	1	/* 14 */,
	2	/* 15 */,
	2	/* 16 */,
	2	/* 17 */,
	3	/* 18/00-18/09 */,
	3	/* 18/10-18/19 */,
	3	/* 18/20-18/29 */,
	3	/* 18/30-18/39 */,
	3	/* 18/40-18/49 */,
	4	/* 18/50-18/59 */,
	4	/* 18/60-18/69 */,
	5	/* 18/70-18/79 */,
	5	/* 18/80-18/89 */,
	6	/* 18/90-18/99 */,
	7	/* 18/100-18/109 */,
	8	/* 18/110-18/119 */,
	9	/* 18/120-18/129 */,
	10	/* 18/130-18/139 */,
	11	/* 18/140-18/149 */,
	12	/* 18/150-18/159 */,
	13	/* 18/160-18/169 */,
	14	/* 18/170-18/179 */,
	15	/* 18/180-18/189 */,
	16	/* 18/190-18/199 */,
	17	/* 18/200-18/209 */,
	18	/* 18/210-18/219 */,
	19	/* 18/220+ */
};

/*
 * Stat Table (WIS) -- Max sanity points
 */
byte adj_wis_msane[] =
{
	128 + -5	/* 3 */,
	128 + -4	/* 4 */,
	128 + -3	/* 5 */,
	128 + -2	/* 6 */,
	128 + -2	/* 7 */,
	128 + -1	/* 8 */,
	128 + -1	/* 9 */,
	128 + 0	/* 10 */,
	128 + 0	/* 11 */,
	128 + 0	/* 12 */,
	128 + 0	/* 13 */,
	128 + 1	/* 14 */,
	128 + 1	/* 15 */,
	128 + 1	/* 16 */,
	128 + 2	/* 17 */,
	128 + 2	/* 18/00-18/09 */,
	128 + 2	/* 18/10-18/19 */,
	128 + 3	/* 18/20-18/29 */,
	128 + 3	/* 18/30-18/39 */,
	128 + 4	/* 18/40-18/49 */,
	128 + 4	/* 18/50-18/59 */,
	128 + 5	/* 18/60-18/69 */,
	128 + 5	/* 18/70-18/79 */,
	128 + 6	/* 18/80-18/89 */,
	128 + 6	/* 18/90-18/99 */,
	128 + 7	/* 18/100-18/109 */,
	128 + 8	/* 18/110-18/119 */,
	128 + 8	/* 18/120-18/129 */,
	128 + 9	/* 18/130-18/139 */,
	128 + 10	/* 18/140-18/149 */,
	128 + 10	/* 18/150-18/159 */,
	128 + 11	/* 18/160-18/169 */,
	128 + 12	/* 18/170-18/179 */,
	128 + 12	/* 18/180-18/189 */,
	128 + 13	/* 18/190-18/199 */,
	128 + 14	/* 18/200-18/209 */,
	128 + 14	/* 18/210-18/219 */,
	128 + 15	/* 18/220+ */
};


/*
 * Stat Table (DEX) -- disarming
 */
byte adj_dex_dis[] =
{
	0	/* 3 */,
	0	/* 4 */,
	0	/* 5 */,
	0	/* 6 */,
	0	/* 7 */,
	0	/* 8 */,
	0	/* 9 */,
	0	/* 10 */,
	0	/* 11 */,
	0	/* 12 */,
	1	/* 13 */,
	1	/* 14 */,
	1	/* 15 */,
	2	/* 16 */,
	2	/* 17 */,
	3	/* 18/00-18/09 */,
	3	/* 18/10-18/19 */,
	3	/* 18/20-18/29 */,
	4	/* 18/30-18/39 */,
	4	/* 18/40-18/49 */,
	5	/* 18/50-18/59 */,
	5	/* 18/60-18/69 */,
	6	/* 18/70-18/79 */,
	6	/* 18/80-18/89 */,
	7	/* 18/90-18/99 */,
	8	/* 18/100-18/109 */,
	8	/* 18/110-18/119 */,
	8	/* 18/120-18/129 */,
	8	/* 18/130-18/139 */,
	8	/* 18/140-18/149 */,
	9	/* 18/150-18/159 */,
	9	/* 18/160-18/169 */,
	9	/* 18/170-18/179 */,
	9	/* 18/180-18/189 */,
	9	/* 18/190-18/199 */,
	10	/* 18/200-18/209 */,
	10	/* 18/210-18/219 */,
	11	/* 18/220+ */
};


/*
 * Stat Table (INT) -- disarming
 */
byte adj_int_dis[] =
{
	0	/* 3 */,
	0	/* 4 */,
	0	/* 5 */,
	0	/* 6 */,
	0	/* 7 */,
	1	/* 8 */,
	1	/* 9 */,
	1	/* 10 */,
	1	/* 11 */,
	1	/* 12 */,
	1	/* 13 */,
	1	/* 14 */,
	2	/* 15 */,
	2	/* 16 */,
	2	/* 17 */,
	3	/* 18/00-18/09 */,
	3	/* 18/10-18/19 */,
	3	/* 18/20-18/29 */,
	4	/* 18/30-18/39 */,
	4	/* 18/40-18/49 */,
	5	/* 18/50-18/59 */,
	6	/* 18/60-18/69 */,
	7	/* 18/70-18/79 */,
	8	/* 18/80-18/89 */,
	9	/* 18/90-18/99 */,
	10	/* 18/100-18/109 */,
	10	/* 18/110-18/119 */,
	11	/* 18/120-18/129 */,
	12	/* 18/130-18/139 */,
	13	/* 18/140-18/149 */,
	14	/* 18/150-18/159 */,
	15	/* 18/160-18/169 */,
	16	/* 18/170-18/179 */,
	17	/* 18/180-18/189 */,
	18	/* 18/190-18/199 */,
	19	/* 18/200-18/209 */,
	19	/* 18/210-18/219 */,
	19	/* 18/220+ */
};


/*
 * Stat Table (DEX) -- bonus to ac (plus 128)
 */
byte adj_dex_ta[] =
{
	128 + -4	/* 3 */,
	128 + -3	/* 4 */,
	128 + -2	/* 5 */,
	128 + -1	/* 6 */,
	128 + 0	/* 7 */,
	128 + 0	/* 8 */,
	128 + 0	/* 9 */,
	128 + 0	/* 10 */,
	128 + 0	/* 11 */,
	128 + 0	/* 12 */,
	128 + 0	/* 13 */,
	128 + 0	/* 14 */,
	128 + 1	/* 15 */,
	128 + 1	/* 16 */,
	128 + 1	/* 17 */,
	128 + 2	/* 18/00-18/09 */,
	128 + 2	/* 18/10-18/19 */,
	128 + 2	/* 18/20-18/29 */,
	128 + 2	/* 18/30-18/39 */,
	128 + 2	/* 18/40-18/49 */,
	128 + 3	/* 18/50-18/59 */,
	128 + 3	/* 18/60-18/69 */,
	128 + 3	/* 18/70-18/79 */,
	128 + 4	/* 18/80-18/89 */,
	128 + 5	/* 18/90-18/99 */,
	128 + 6	/* 18/100-18/109 */,
	128 + 7	/* 18/110-18/119 */,
	128 + 8	/* 18/120-18/129 */,
	128 + 9	/* 18/130-18/139 */,
	128 + 9	/* 18/140-18/149 */,
	128 + 10	/* 18/150-18/159 */,
	128 + 10	/* 18/160-18/169 */,
	128 + 11	/* 18/170-18/179 */,
	128 + 11	/* 18/180-18/189 */,
	128 + 12	/* 18/190-18/199 */,
	128 + 13	/* 18/200-18/209 */,
	128 + 13	/* 18/210-18/219 */,
	128 + 14	/* 18/220+ */
};


/*
 * Stat Table (STR) -- bonus to dam (plus 128)
 */
byte adj_str_td[] =
{
	128 + -2	/* 3 */,
	128 + -2	/* 4 */,
	128 + -1	/* 5 */,
	128 + -1	/* 6 */,
	128 + 0	/* 7 */,
	128 + 0	/* 8 */,
	128 + 0	/* 9 */,
	128 + 0	/* 10 */,
	128 + 0	/* 11 */,
	128 + 0	/* 12 */,
	128 + 0	/* 13 */,
	128 + 0	/* 14 */,
	128 + 1	/* 15 */,
	128 + 1	/* 16 */,
	128 + 2	/* 17 */,
	128 + 2	/* 18/00-18/09 */,
	128 + 2	/* 18/10-18/19 */,
	128 + 3	/* 18/20-18/29 */,
	128 + 3	/* 18/30-18/39 */,
	128 + 3	/* 18/40-18/49 */,
	128 + 3	/* 18/50-18/59 */,
	128 + 3	/* 18/60-18/69 */,
	128 + 4	/* 18/70-18/79 */,
	128 + 5	/* 18/80-18/89 */,
	128 + 5	/* 18/90-18/99 */,
	128 + 6	/* 18/100-18/109 */,
	128 + 7	/* 18/110-18/119 */,
	128 + 8	/* 18/120-18/129 */,
	128 + 9	/* 18/130-18/139 */,
	128 + 10	/* 18/140-18/149 */,
	128 + 11	/* 18/150-18/159 */,
	128 + 12	/* 18/160-18/169 */,
	128 + 13	/* 18/170-18/179 */,
	128 + 14	/* 18/180-18/189 */,
	128 + 15	/* 18/190-18/199 */,
	128 + 16	/* 18/200-18/209 */,
	128 + 18	/* 18/210-18/219 */,
	128 + 20	/* 18/220+ */
};


/*
 * Stat Table (DEX) -- bonus to hit (plus 128)
 */
byte adj_dex_th[] =
{
	20	/* 3 */,
	30	/* 4 */,
	40	/* 5 */,
	50	/* 6 */,
	60	/* 7 */,
	70	/* 8 */,
	75	/* 9 */,
	80	/* 10 */,
	85	/* 11 */,
	89	/* 12 */,
	93	/* 13 */,
	97	/* 14 */,
	100	/* 15 */,
	103	/* 16 */,
	106	/* 17 */,
	109	/* 18/00-18/09 */,
	111	/* 18/10-18/19 */,
	113	/* 18/20-18/29 */,
	115	/* 18/30-18/39 */,
	116	/* 18/40-18/49 */,
	117	/* 18/50-18/59 */,
	118	/* 18/60-18/69 */,
	119	/* 18/70-18/79 */,
	120	/* 18/80-18/89 */,
	121	/* 18/90-18/99 */,
	122	/* 18/100-18/109 */,
	123	/* 18/110-18/119 */,
	124	/* 18/120-18/129 */,
	125	/* 18/130-18/139 */,
	126	/* 18/140-18/149 */,
	126	/* 18/150-18/159 */,
	127	/* 18/160-18/169 */,
	127	/* 18/170-18/179 */,
	128	/* 18/180-18/189 */,
	128	/* 18/190-18/199 */,
	129	/* 18/200-18/209 */,
	129	/* 18/210-18/219 */,
	130	/* 18/220+ */
};


/*
 * Stat Table (STR) -- bonus to hit (plus 128)
 */
byte adj_str_th[] =
{
	128 + -3	/* 3 */,
	128 + -2	/* 4 */,
	128 + -1	/* 5 */,
	128 + -1	/* 6 */,
	128 + 0	/* 7 */,
	128 + 0	/* 8 */,
	128 + 0	/* 9 */,
	128 + 0	/* 10 */,
	128 + 0	/* 11 */,
	128 + 0	/* 12 */,
	128 + 0	/* 13 */,
	128 + 0	/* 14 */,
	128 + 0	/* 15 */,
	128 + 0	/* 16 */,
	128 + 0	/* 17 */,
	128 + 1	/* 18/00-18/09 */,
	128 + 1	/* 18/10-18/19 */,
	128 + 1	/* 18/20-18/29 */,
	128 + 1	/* 18/30-18/39 */,
	128 + 1	/* 18/40-18/49 */,
	128 + 1	/* 18/50-18/59 */,
	128 + 1	/* 18/60-18/69 */,
	128 + 2	/* 18/70-18/79 */,
	128 + 3	/* 18/80-18/89 */,
	128 + 4	/* 18/90-18/99 */,
	128 + 5	/* 18/100-18/109 */,
	128 + 6	/* 18/110-18/119 */,
	128 + 7	/* 18/120-18/129 */,
	128 + 8	/* 18/130-18/139 */,
	128 + 9	/* 18/140-18/149 */,
	128 + 10	/* 18/150-18/159 */,
	128 + 11	/* 18/160-18/169 */,
	128 + 12	/* 18/170-18/179 */,
	128 + 13	/* 18/180-18/189 */,
	128 + 14	/* 18/190-18/199 */,
	128 + 15	/* 18/200-18/209 */,
	128 + 15	/* 18/210-18/219 */,
	128 + 15	/* 18/220+ */
};


/*
 * Stat Table (STR) -- weight limit in deca-pounds
 */
byte adj_str_wgt[] =
{
	5	/* 3 */,
	6	/* 4 */,
	7	/* 5 */,
	8	/* 6 */,
	9	/* 7 */,
	10	/* 8 */,
	11	/* 9 */,
	12	/* 10 */,
	13	/* 11 */,
	14	/* 12 */,
	15	/* 13 */,
	16	/* 14 */,
	17	/* 15 */,
	18	/* 16 */,
	19	/* 17 */,
	20	/* 18/00-18/09 */,
	22	/* 18/10-18/19 */,
	24	/* 18/20-18/29 */,
	26	/* 18/30-18/39 */,
	28	/* 18/40-18/49 */,
	30	/* 18/50-18/59 */,
	30	/* 18/60-18/69 */,
	30	/* 18/70-18/79 */,
	30	/* 18/80-18/89 */,
	30	/* 18/90-18/99 */,
	30	/* 18/100-18/109 */,
	30	/* 18/110-18/119 */,
	30	/* 18/120-18/129 */,
	30	/* 18/130-18/139 */,
	30	/* 18/140-18/149 */,
	30	/* 18/150-18/159 */,
	30	/* 18/160-18/169 */,
	30	/* 18/170-18/179 */,
	30	/* 18/180-18/189 */,
	30	/* 18/190-18/199 */,
	30	/* 18/200-18/209 */,
	30	/* 18/210-18/219 */,
	30	/* 18/220+ */
};


/*
 * Stat Table (STR) -- weapon weight limit in pounds
 */
byte adj_str_hold[] =
{
	4	/* 3 */,
	5	/* 4 */,
	6	/* 5 */,
	7	/* 6 */,
	8	/* 7 */,
	10	/* 8 */,
	12	/* 9 */,
	14	/* 10 */,
	16	/* 11 */,
	18	/* 12 */,
	20	/* 13 */,
	22	/* 14 */,
	24	/* 15 */,
	26	/* 16 */,
	28	/* 17 */,
	30	/* 18/00-18/09 */,
	30	/* 18/10-18/19 */,
	35	/* 18/20-18/29 */,
	40	/* 18/30-18/39 */,
	45	/* 18/40-18/49 */,
	50	/* 18/50-18/59 */,
	55	/* 18/60-18/69 */,
	60	/* 18/70-18/79 */,
	65	/* 18/80-18/89 */,
	70	/* 18/90-18/99 */,
	80	/* 18/100-18/109 */,
	80	/* 18/110-18/119 */,
	80	/* 18/120-18/129 */,
	80	/* 18/130-18/139 */,
	80	/* 18/140-18/149 */,
	90	/* 18/150-18/159 */,
	90	/* 18/160-18/169 */,
	90	/* 18/170-18/179 */,
	90	/* 18/180-18/189 */,
	90	/* 18/190-18/199 */,
	100	/* 18/200-18/209 */,
	100	/* 18/210-18/219 */,
	100	/* 18/220+ */
};


/*
 * Stat Table (STR) -- digging value
 */
byte adj_str_dig[] =
{
	0	/* 3 */,
	0	/* 4 */,
	1	/* 5 */,
	2	/* 6 */,
	3	/* 7 */,
	4	/* 8 */,
	4	/* 9 */,
	5	/* 10 */,
	5	/* 11 */,
	6	/* 12 */,
	6	/* 13 */,
	7	/* 14 */,
	7	/* 15 */,
	8	/* 16 */,
	8	/* 17 */,
	9	/* 18/00-18/09 */,
	10	/* 18/10-18/19 */,
	12	/* 18/20-18/29 */,
	15	/* 18/30-18/39 */,
	18	/* 18/40-18/49 */,
	21	/* 18/50-18/59 */,
	25	/* 18/60-18/69 */,
	30	/* 18/70-18/79 */,
	35	/* 18/80-18/89 */,
	40	/* 18/90-18/99 */,
	45	/* 18/100-18/109 */,
	50	/* 18/110-18/119 */,
	55	/* 18/120-18/129 */,
	60	/* 18/130-18/139 */,
	65	/* 18/140-18/149 */,
	70	/* 18/150-18/159 */,
	75	/* 18/160-18/169 */,
	80	/* 18/170-18/179 */,
	85	/* 18/180-18/189 */,
	90	/* 18/190-18/199 */,
	95	/* 18/200-18/209 */,
	95	/* 18/210-18/219 */,
	100	/* 18/220+ */
};


/*
 * Stat Table (STR) -- help index into the "blow" table
 */
byte adj_str_blow[] =
{
	3	/* 3 */,
	4	/* 4 */,
	5	/* 5 */,
	6	/* 6 */,
	7	/* 7 */,
	8	/* 8 */,
	9	/* 9 */,
	10	/* 10 */,
	11	/* 11 */,
	12	/* 12 */,
	13	/* 13 */,
	14	/* 14 */,
	15	/* 15 */,
	16	/* 16 */,
	17	/* 17 */,
	20 /* 18/00-18/09 */,
	30 /* 18/10-18/19 */,
	40 /* 18/20-18/29 */,
	50 /* 18/30-18/39 */,
	60 /* 18/40-18/49 */,
	70 /* 18/50-18/59 */,
	80 /* 18/60-18/69 */,
	90 /* 18/70-18/79 */,
	100 /* 18/80-18/89 */,
	110 /* 18/90-18/99 */,
	120 /* 18/100-18/109 */,
	130 /* 18/110-18/119 */,
	140 /* 18/120-18/129 */,
	150 /* 18/130-18/139 */,
	160 /* 18/140-18/149 */,
	170 /* 18/150-18/159 */,
	180 /* 18/160-18/169 */,
	190 /* 18/170-18/179 */,
	200 /* 18/180-18/189 */,
	210 /* 18/190-18/199 */,
	220 /* 18/200-18/209 */,
	230 /* 18/210-18/219 */,
	240 /* 18/220+ */
/*	266 (to get 6 bpr at 400 lb weapon weight) not possible since type is byte. Work-around via hack in calc_blows. - C. Blue */
};


/*
 * Stat Table (STR) -- orientation for create_reward, concerning armor weight
 */
byte adj_str_armor[] =
{
	2	/* 3 */,
	2	/* 4 */,
	2	/* 5 */,
	2	/* 6 */,
	3	/* 7 */,
	3	/* 8 */,
	4	/* 9 */,
	4	/* 10 */,
	5	/* 11 */,
	5	/* 12 */,
	7	/* 13 */,
	9	/* 14 */,
	11	/* 15 */,
	13	/* 16 */,
	14	/* 17 */,
	15 /* 18/00-18/09 */,
	16 /* 18/10-18/19 */,
	18 /* 18/20-18/29 - 200 is max. weight for TV_SOFT_ARMOR */,
	20 /* 18/30-18/39 - 200 is min. weight for TV_HARD_ARMOR */,
	22 /* 18/40-18/49 */,
	24 /* 18/50-18/59 */,
	26 /* 18/60-18/69 */,
	28 /* 18/70-18/79 */,
	30 /* 18/80-18/89 */,
	32 /* 18/90-18/99 */,
	35 /* 18/100-18/109 */,
	38 /* 18/110-18/119 */,
	41 /* 18/120-18/129 */,
	44 /* 18/130-18/139 */,
	47 /* 18/140-18/149 */,
	50 /* 18/150-18/159 */,
	50 /* 18/160-18/169 */,
	50 /* 18/170-18/179 */,
	50 /* 18/180-18/189 */,
	50 /* 18/190-18/199 */,
	50 /* 18/200-18/209 */,
	50 /* 18/210-18/219 */,
	50 /* 18/220+ - 500 is just a limit value in create_reward() */
};


/*
 * Stat Table (DEX) -- index into the "blow" table
 */
byte adj_dex_blow[] =
{
	0	/* 3 */,
	0	/* 4 */,
	0	/* 5 */,
	0	/* 6 */,
	0	/* 7 */,
	0	/* 8 */,
	0	/* 9 */,
	1	/* 10 */,
	1	/* 11 */,
	1	/* 12 */,
	1	/* 13 */,
	1	/* 14 */,
	1	/* 15 */,
	1	/* 16 */,
	1	/* 17 */,
	1	/* 18/00-18/09 */,
	2	/* 18/10-18/19 */,
	2	/* 18/20-18/29 */,
	2	/* 18/30-18/39 */,
	2	/* 18/40-18/49 */,
	3	/* 18/50-18/59 */,
	3	/* 18/60-18/69 */,
	4	/* 18/70-18/79 */,
	4	/* 18/80-18/89 */,
	5	/* 18/90-18/99 */,
	6	/* 18/100-18/109 */,
	7	/* 18/110-18/119 */,
	8	/* 18/120-18/129 */,
	9	/* 18/130-18/139 */,
	10	/* 18/140-18/149 */,
	11	/* 18/150-18/159 */,
	12	/* 18/160-18/169 */,
	14	/* 18/170-18/179 */,
	16	/* 18/180-18/189 */,
	18	/* 18/190-18/199 */,
	20	/* 18/200-18/209 */,
	20	/* 18/210-18/219 */,
	20	/* 18/220+ */
};


/*
 * Stat Table (DEX) -- chance of avoiding "theft" and "falling"
 */
byte adj_dex_safe[] =
{
	0	/* 3 */,
	1	/* 4 */,
	2	/* 5 */,
	3	/* 6 */,
	4	/* 7 */,
	5	/* 8 */,
	5	/* 9 */,
	6	/* 10 */,
	6	/* 11 */,
	7	/* 12 */,
	7	/* 13 */,
	8	/* 14 */,
	8	/* 15 */,
	9	/* 16 */,
	9	/* 17 */,
	10	/* 18/00-18/09 */,
	10	/* 18/10-18/19 */,
	15	/* 18/20-18/29 */,
	15	/* 18/30-18/39 */,
	20	/* 18/40-18/49 */,
	25	/* 18/50-18/59 */,
	30	/* 18/60-18/69 */,
	35	/* 18/70-18/79 */,
	40	/* 18/80-18/89 */,
	45	/* 18/90-18/99 */,
	50	/* 18/100-18/109 */,
	55	/* 18/110-18/119 */,
	60	/* 18/120-18/129 */,
	65	/* 18/130-18/139 */,
	70	/* 18/140-18/149 */,
	75	/* 18/150-18/159 */,
	80	/* 18/160-18/169 */,
	85	/* 18/170-18/179 */,
	90	/* 18/180-18/189 */,
	90	/* 18/190-18/199 */,
	95	/* 18/200-18/209 */,
	95	/* 18/210-18/219 */,
	100	/* 18/220+ */
};


/*
 * Stat Table (CON) -- base regeneration rate
 */
byte adj_con_fix[] =
{
	0	/* 3 */,
	0	/* 4 */,
	0	/* 5 */,
	0	/* 6 */,
	0	/* 7 */,
	0	/* 8 */,
	0	/* 9 */,
	0	/* 10 */,
	0	/* 11 */,
	0	/* 12 */,
	0	/* 13 */,
	1	/* 14 */,
	1	/* 15 */,
	1	/* 16 */,
	1	/* 17 */,
	2	/* 18/00-18/09 */,
	2	/* 18/10-18/19 */,
	2	/* 18/20-18/29 */,
	2	/* 18/30-18/39 */,
	2	/* 18/40-18/49 */,
	3	/* 18/50-18/59 */,
	3	/* 18/60-18/69 */,
	3	/* 18/70-18/79 */,
	3	/* 18/80-18/89 */,
	3	/* 18/90-18/99 */,
	4	/* 18/100-18/109 */,
	4	/* 18/110-18/119 */,
	4	/* 18/120-18/129 */,
	5	/* 18/130-18/139 */,
	5	/* 18/140-18/149 */,
	6	/* 18/150-18/159 */,
	6	/* 18/160-18/169 */,
	7	/* 18/170-18/179 */,
	7	/* 18/180-18/189 */,
	8	/* 18/190-18/199 */,
	8	/* 18/200-18/209 */,
	9	/* 18/210-18/219 */,
	9	/* 18/220+ */
};


/*
 * Stat Table (CON) -- extra half-hitpoints per level (plus 128)
 */
byte adj_con_mhp[] =
{
	128 + -5	/* 3 */,
	128 + -3	/* 4 */,
	128 + -2	/* 5 */,
	128 + -1	/* 6 */,
	128 + -1	/* 7 */,
	128 + 0	/* 8 */,
	128 + 0	/* 9 */,
	128 + 0	/* 10 */,
	128 + 0	/* 11 */,
	128 + 0	/* 12 */,
	128 + 0	/* 13 */,
	128 + 1	/* 14 */,
	128 + 1	/* 15 */,
	128 + 1	/* 16 */,
	128 + 2	/* 17 */,
	128 + 3	/* 18/00-18/09 */,
	128 + 4	/* 18/10-18/19 */,
	128 + 4	/* 18/20-18/29 */,
	128 + 4	/* 18/30-18/39 */,
	128 + 5	/* 18/40-18/49 */,
	128 + 5	/* 18/50-18/59 */,
	128 + 6	/* 18/60-18/69 */,
	128 + 7	/* 18/70-18/79 */,
	128 + 8	/* 18/80-18/89 */,
	128 + 9	/* 18/90-18/99 */,
	128 + 10	/* 18/100-18/109 */,
	128 + 11	/* 18/110-18/119 */,
	128 + 12	/* 18/120-18/129 */,
	128 + 13	/* 18/130-18/139 */,
	128 + 14	/* 18/140-18/149 */,
	128 + 15	/* 18/150-18/159 */,
	128 + 16	/* 18/160-18/169 */,
	128 + 18	/* 18/170-18/179 */,
	128 + 20	/* 18/180-18/189 */,
	128 + 22	/* 18/190-18/199 */,
	128 + 23	/* 18/200-18/209 */,
	128 + 24	/* 18/210-18/219 */,
	128 + 25	/* 18/220+ */
};


/*
 * This table is used to help calculate the number of blows the player can
 * make in a single round of attacks (one player turn) with a normal weapon.
 *
 * This number ranges from a single blow/round for weak players to up to six
 * blows/round for powerful warriors.
 *
 * Note that certain artifacts and ego-items give "bonus" blows/round.
 *
 * First, from the player class, we extract some values:
 *
 *    Warrior --> num = 6; mul = 5; div = MAX(30, weapon_weight);
 *    Mage    --> num = 4; mul = 2; div = MAX(40, weapon_weight);
 *    Priest  --> num = 5; mul = 3; div = MAX(35, weapon_weight);
 *    Rogue   --> num = 5; mul = 3; div = MAX(30, weapon_weight);
 *    Ranger  --> num = 5; mul = 4; div = MAX(35, weapon_weight);
 *    Paladin --> num = 5; mul = 4; div = MAX(30, weapon_weight);
 *
 * To get "P", we look up the relevant "adj_str_blow[]" (see above),
 * multiply it by "mul", and then divide it by "div", rounding down.
 *
 * To get "D", we look up the relevant "adj_dex_blow[]" (see above),
 * note especially column 6 (DEX 18/101) and 11 (DEX 18/150).
 *
 * The player gets "blows_table[P][D]" blows/round, as shown below,
 * up to a maximum of "num" blows/round, plus any "bonus" blows/round.
 */
byte blows_table[12][12] =
{
	/* P/D */
	/* 0,   1,   2,   3,   4,   5,   6,   7,   8,   9,  10,  11+ */

	/* 0  */
	{  1,   1,   1,   1,   1,   1,   2,   2,   2,   2,   2,   3 },

	/* 1  */
	{  1,   1,   1,   1,   2,   2,   3,   3,   3,   4,   4,   4 },

	/* 2  */
	{  1,   1,   2,   2,   3,   3,   4,   4,   4,   5,   5,   5 },

	/* 3  */
	{  1,   2,   2,   3,   3,   4,   4,   4,   5,   5,   5,   5 },

	/* 4  */
	{  1,   2,   2,   3,   3,   4,   4,   5,   5,   5,   5,   5 },

	/* 5  */
	{  2,   2,   3,   3,   4,   4,   5,   5,   5,   5,   5,   6 },

	/* 6  */
	{  2,   2,   3,   3,   4,   4,   5,   5,   5,   5,   5,   6 },

	/* 7  */
	{  2,   3,   3,   4,   4,   4,   5,   5,   5,   5,   5,   6 },

	/* 8  */
	{  3,   3,   3,   4,   4,   4,   5,   5,   5,   5,   6,   6 },

	/* 9  */
	{  3,   3,   4,   4,   4,   4,   5,   5,   5,   5,   6,   6 },

	/* 10 */
	{  3,   3,   4,   4,   4,   4,   5,   5,   5,   6,   6,   6 },

	/* 11+ */
	{  3,   3,   4,   4,   4,   4,   5,   5,   6,   6,   6,   7 },
};


/*
 * This table allows quick conversion from "speed" to "energy"
 * The basic function WAS ((S>=110) ? (S-110) : (100 / (120-S)))
 * Note that table access is *much* quicker than computation.
 *
 * Note that the table has been changed at high speeds.  From
 * "Slow (-40)" to "Fast (+30)" is pretty much unchanged, but
 * at speeds above "Fast (+30)", one approaches an asymptotic
 * effective limit of 50 energy per turn.  This means that it
 * is relatively easy to reach "Fast (+30)" and get about 40
 * energy per turn, but then speed becomes very "expensive",
 * and you must get all the way to "Fast (+50)" to reach the
 * point of getting 45 energy per turn.  After that point,
 * furthur increases in speed are more or less pointless,
 * except to balance out heavy inventory.
 *
 * Note that currently the fastest monster is "Fast (+30)".
 *
 * It should be possible to lower the energy threshhold from
 * 100 units to 50 units, though this may interact badly with
 * the (compiled out) small random energy boost code.  It may
 * also tend to cause more "clumping" at high speeds.
 */
byte extract_energy[256] =
{
	/* Slow */     1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
	/* Slow */     1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
	/* Slow */     1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
	/* Slow */     1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
	/* Slow */     1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
	/* Slow */     1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
	/* S-50 */     1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
	/* S-40 */     2,  2,  2,  2,  2,  2,  2,  2,  2,  2,
	/* S-30 */     2,  2,  2,  2,  2,  2,  2,  3,  3,  3,
	/* S-20 */     3,  3,  3,  3,  3,  4,  4,  4,  4,  4,
	/* S-10 */     5,  5,  5,  5,  6,  6,  7,  7,  8,  9,
	/* Norm */    10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
	/* F+10 */    20, 21, 22, 23, 24, 25, 26, 27, 28, 29,
	/* F+20 */    30, 31, 32, 33, 34, 35, 36, 37, 38, 39,
	/* F+30 */    40, 41, 42, 43, 44, 45, 46, 47, 48, 49,
	/* F+40 */    50, 51, 52, 53, 54, 54, 55, 55, 56, 57,
	/* F+50 */    58, 58, 59, 60, 61, 62, 63, 63, 64, 64,
	/* F+60 */    65, 65, 66, 66, 67, 67, 68, 68, 69, 69,
	/* F+70 */    70, 70, 71, 71, 72, 72, 73, 73, 74, 74,
	/* Fast */    75, 75, 76, 76, 77, 77, 78, 78, 79, 79,
	/* Fast */    80, 80, 80, 80, 80, 80, 80, 80, 80, 80,
	/* Fast */    80, 80, 80, 80, 80, 80, 80, 80, 80, 80,
	/* Fast */    80, 80, 80, 80, 80, 80, 80, 80, 80, 80,
	/* Fast */    80, 80, 80, 80, 80, 80, 80, 80, 80, 80,
	/* Fast */    80, 80, 80, 80, 80, 80, 80, 80, 80, 80,
	/* Fast */    80, 80, 80, 80, 80, 80
};


/*
 * This table provides for different game speeds at different
 * dungeon depths.  Shallower depths are faster, allowing for
 * easier town navigation.  Deeper depths are slow, hopefully
 * make deep combat less of a test of reflexs.
 */
byte level_speeds[501] =
{
	75,  90,  91,  92,  93,  94,  95,  96,  97,  98, /* Town - 450' */
	99, 100, 100, 100, 100, 100, 101, 102, 103, 104, /* 500' - 950' */
	105, 106, 107, 108, 109, 110, 111, 112, 113, 114, /* 1000' - 1450' */
	115, 116, 117, 118, 119, 120, 121, 122, 123, 124, /* 1500' - 1950' */
	125, 126, 127, 128, 129, 130, 131, 132, 133, 134, /* 2000' - 2450' */
	135, 137, 138, 139, 140, 142, 143, 144, 146, 148, /* 2500' - 2950' */
	150, 152, 154, 156, 158, 160, 162, 164, 166, 168, /* 3000' - 3450' */
	170, 172, 174, 176, 178, 180, 182, 184, 186, 188, /* 3500' - 3950' */
	190, 192, 194, 196, 198, 200, 200, 200, 200, 200, /* 4000' - 4450' */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 4500' - 4950' */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 5000' - 5450' */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 5500' - 5950' */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 120 - 129 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 130 - 139 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 130 - 139 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 130 - 139 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 130 - 139 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 130 - 139 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 130 - 139 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 130 - 139 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 130 - 139 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 5500' - 5950' */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 120 - 129 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 130 - 139 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 130 - 139 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 130 - 139 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 130 - 139 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 130 - 139 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 130 - 139 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 130 - 139 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 130 - 139 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 5500' - 5950' */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 120 - 129 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 130 - 139 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 130 - 139 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 130 - 139 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 130 - 139 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 130 - 139 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 130 - 139 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 130 - 139 */
	200, 200, 200, 200, 200, 200, 200, 200, 200, 200, /* 130 - 139 */
};





/*
 * Base experience levels, may be adjusted up for race and/or class
 */
s32b player_exp[PY_MAX_LEVEL + 1] =
{
	10,
	25,
	45,
	70,//5
	100,
	140,
	200,
	280,
	380,//10
	500,
	650,
	850,
	1100,
	1400,//15
	1800,
	2300,
	2900,
	3600,
	4400,//20
	5400,
	6800,
	8400,
	10200,
	12500,//25
	17500,
	25000,
	35000L,
	50000L,
	75000L,//30
	100000L,
	150000L,
	200000L,
	275000L,
	350000L,//35
	450000L,
	550000L,
	700000L,
	850000L,
	1050000L,//	1000000L,//40
	1300000L,//	1250000L,
	1550000L,//	1500000L,
	1850000L,//	1800000L,
	2150000L,//	2100000L,
	2500000L,//	2400000L,//45
	2900000L,//	2700000L,
	3400000L,//	3000000L,
	4000000L,//	3500000L,
	4800000L,//	4000000L,
	5800000L,//	4500000L,//50
	7000000L,//	5000000L,

	8200000L,//	6000000L,
	9400000L,//	7000000L,
	10800000L,//	8000000L,
	12600000L,//	9000000L,//55
	14600000L,//	10000000L,

	16800000L,//	12000000L,
	19200000L,//	14000000L,
	21800000L,//	16000000L,
	24600000L,//	18000000L,//60
	28000000L,//	20000000L,

	31500000L,//       24000000L,
	35500000L,//       28000000L,
	40000000L,//       32000000L,
	45000000L,//       36000000L,//65
	50500000L,//       40000000L,

	56500000L,//       46000000L,
	63000000L,//       52000000L,
	70000000L,//       58000000L,
	78000000L,//       64000000L,//70
	87000000L,//       70000000L,

	97000000L,//	   78000000L,
        108000000L,//	    86000000L,
	120000000L,//       94000000L,
	133000000L,//      102000000L,//75
	147000000L,//      110000000L,

	162000000L,//      120000000L,
	178000000L,//      130000000L,
	195000000L,//      140000000L,
	213000000L,//      150000000L,//80
	233000000L,//      160000000L,

	255000000L,//      172000000L,
	279000000L,//      184000000L,
	305000000L,//      196000000L,
	333000000L,//      208000000L,//85
	363000000L,//      220000000L,

	395000000L,//      234000000L,
	429000000L,//      248000000L,
	465000000L,//      262000000L,
	503000000L,//      276000000L,//90
	543000000L,//      290000000L,

	585000000L,//      304000000L,
	629000000L,//      318000000L,
	675000000L,//      332000000L,
	723000000L,//      346000000L,//95
	773000000L,//      360000000L,

	825000000L,//      380000000L,
	880000000L,//      400000000L,
//	938000000L,//      420000000L,//99, PY_MAX_PLAYER_LEVEL
	940000000L,//      420000000L,//99, PY_MAX_PLAYER_LEVEL
	999000000L,//      440000000L,//100 PY_MAX_LEVEL
	999999998L,//      460000000L,//<-not sure why 101 and the 'dummy' one for 102 are needed tho

	999999999L // dummy, == PY_MAX_EXP
};


/*
 * Player Race Information:
 *    Title,
 *    {STR,INT,WIS,DEX,CON,CHR},
 *    r_dis, r_dev, r_sav, r_stl, r_srh, r_fos, r_thn, r_thb,
 *    hitdie, exp base,
 *    Age (Base, Mod),
 *    Male (Hgt, Wgt),
 *    Female (Hgt, Wgt)
 *    infra,
 *    class-choices
 *    mana %  (<- obsolete)
 */
player_race race_info[MAX_RACE] =
{
        {
                "Human",
                {  0,  0,  0,  0,  0,  0 },
                0,  0,  0,  0,  0,  10,  0,  0,
                10,  100,
                14,  6,
                72,  6, 180, 25,
                66,  4, 150, 20,
                0,
//                0xFFFFFFFF,
		CFW+CFI+CFP+CFR+CFM+CFA+CFL+CFN+CFX+CFD+CFS+CFU+CFC,
                100,
                {
                        /* HUMAN POWER!! */
                        {
//                                SKILL_TRAINING,
                                SKILL_INTERCEPT,
                                '+', 1000,
                                '%', 115,
                        },
                        {
                                SKILL_CLIMB,
                                '+', 0,
                                '+', 50,
                        },
                        {
                                SKILL_SWIM,
                                '+', 0,
                                '+', 50,
                        },
                        {
                                SKILL_SHOOT_TILL_KILL,
                                '+', 1000,
                                '+', 0,
                        },
                },
        },

        {
                "Half-Elf",
                { -1,  1,  0,  1, -1,  1 },
                2,  5,  3,  1, 6,  11, -1,  5,
                9,  110,
                24, 16,
                66,  6, 130, 15,
                62,  6, 100, 10,
                2,
//                0xFFFFFFFF,
		CFW+CFI+CFP+CFR+CFM+CFA+CFL+CFN+CFX+CFD+CFS+CFU+CFC,
                110,
                {
                        {
                                SKILL_BOW,
                                '+', 0,
                                '%', 110,
                        },
                        {
//                                SKILL_TRAINING,
				SKILL_INTERCEPT,
                                '+', 500,
                                '%', 110,
                        },
                        {
                                SKILL_CLIMB,
                                '+', 0,
                                '+', 40,
                        },
                        {
                                SKILL_SWIM,
                                '+', 0,
                                '+', 50,
                        },
                        {
                                SKILL_SHOOT_TILL_KILL,
                                '+', 1000,
                                '+', 0,
                        },
                },
        },

        {
                "Elf",
                { -1,  2,  1,  1, -2,  2 },
                5,  9,  6,  2, 8,  12, -5, 15,
                8,  120,
                75, 75,
                60,  4, 100,  6,
                54,  4, 80,  6,
                3,
//  111011101101 -> 101101110111
// 0xB77 -> EED
//		0xB77,
		CFW+CFI+CFR+CFM+CFA+CFN+CFX+CFD+CFU+CFC,
                120,
                {
                        {
                                SKILL_BOW,
                                '+', 1000,
                                '%', 110,
                        },
                        {
                                SKILL_MAGIC,
                                '+', 0,
                                '%', 110,
                        },
                        {
                                SKILL_STEALTH,
                                '+', 0,
                                '%', 110,
                        },
                        {
                                SKILL_DODGE,
                                '+', 0,/*1000*/
                                '%', 110,
                        },
                        {
                                SKILL_AGILITY,
                                '+', 1000,
                                '%', 110,
                        },
                        {
                                SKILL_CALMNESS,
                                '+', 1000,
                                '%', 110,
                        },
                        {
                                SKILL_SNEAKINESS,
                                '+', 1000,
                                '%', 110,
                        },
                        {
                                SKILL_CLIMB,
                                '+', 0,
                                '+', 40,
                        },
                        {
                                SKILL_SWIM,
                                '+', 0,
                                '+', 50,
                        },
                        {
                                SKILL_SHOOT_TILL_KILL,
                                '+', 1000,
                                '+', 0,
                        },
                },
        },

        {
                "Hobbit",
                { -2,  2,  1,  3,  0,  1 },
                15, 12, 18, 4, 12,  15, -10, 20,
//                7,  110,
                7,  115,
                21, 12,
                36,  3, 60,  3,
                33,  3, 50,  3,
                3,
//                0xF77, 111101110111 -> 111011101111
//		0xEEF,
//		0xF77,
//		0xF7F,
		CFW+CFI+CFP+CFR+CFM+CFA+CFN+CFX+CFD+CFS+CFU+CFC,
                90,
                {
                        {
                                SKILL_SLING,
                                '+', 1000,
                                '%', 110,
                        },
                        {
                                SKILL_STEALTH,
                                '+', 1000,
                                '%', 115,
                        },
                        {
                                SKILL_SNEAKINESS,
                                '+', 2000,
                                '%', 110,
                        },
                        {
                                SKILL_DODGE,
                                '+', 0,/*1000*/
                                '%', 110,
                        },
                        {
                                SKILL_CLIMB,
                                '+', 0,
                                '+', 40,
                        },
                        {
                                SKILL_SWIM,
                                '+', 0,
                                '+', 50,
                        },
                        {
                                SKILL_SHOOT_TILL_KILL,
                                '+', 1000,
                                '+', 0,
                        },
                },
        },

        {
                "Gnome",
                { -1,  2,  0,  2,  1, -2 },
                10, 18, 12,  3, 6,  13, -8, 12,
                8,  125,
                50, 40,
                42,  3, 90,  6,
                39,  3, 75,  3,
                4,
//                0xC77, 110001110111 -> 111011100011
//		0xEE3,
//		0xC77,
		CFW+CFI+CFR+CFM+CFA+CFX+CFD+CFS+CFU+CFC,
                120,
                {
                        {
                                SKILL_XBOW,
                                '+', 1000,
                                '%', 110,
                        },
                        {
                                SKILL_MAGIC,
                                '+', 0,
                                '%', 110,
                        },
                        {
                                SKILL_DIG,
                                '+', 1000,
                                '%', 115,
                        },
                        {
                                SKILL_DODGE,
                                '+', 0,/*1000*/
                                '%', 115,
                        },
                        {
                                SKILL_CLIMB,
                                '+', 0,
                                '+', 40,
                        },
                        {
                                SKILL_SWIM,
                                '+', 0,
                                '+', 50,
                        },
                        {
                                SKILL_SHOOT_TILL_KILL,
                                '+', 1000,
                                '+', 0,
                        },
                },
        },

        {
                "Dwarf",
                {  2, -2,  2, -2,  2, -3 },
                2,  9,  9,  -1,  7,  10, 15,  0,
                11,  130,
                35, 15,
                48,  3, 150, 10,
                46,  3, 120, 10,
                5,
//                0x7FB, 011111111011 -> 010111111110
//		0xDFE,
//		0x7FB,
		CFW+CFP+CFR+CFM+CFA+CFL+CFX+CFD+CFS+CFU,
                95,
                {
                        {
                                SKILL_AXE,
                                '+', 0,
                                '%', 110,
                        },
                        {
                                SKILL_DIG,
                                '+', 5000,
                                '%', 130,
                        },
                        {
                                SKILL_CLIMB,
                                '+', 0,
                                '+', 60,
                        },
                        {
                                SKILL_SWIM,
                                '+', 0,
                                '+', 40,
                        },
                        {
                                SKILL_SHOOT_TILL_KILL,
                                '+', 1000,
                                '+', 0,
                        },
                },
        },

        {
                "Half-Orc",
                {  2, -1,  0,  0,  1, -4 },
                -3, -3, -3,  -1,  0, 7, 12, -5,
                11,  115, // lowered from 110 to 100
                11,  4,
                66,  1, 150,  5,
                62,  1, 120,  5,
                3,
//                0xF7B, 111101111011 -> 010111101111
//0101-1110-1111 0x5EF
//0101-0111-1011 0x57B
//		0x5EF,
//		0x57B,
		CFW+CFP+CFR+CFM+CFA+CFX+CFS,
                50,
                {
                        {
                                SKILL_BACKSTAB,
                                '+', 1000,
                                '%', 105,
                        },
                        {
                                SKILL_MASTERY,
                                '+', 0,
                                '%', 115,
                        },
                        {
                                SKILL_NECROMANCY,
                                '+', 0,
                                '%', 110,
                        },
                        /* Not banned, but hard */
                        {
                                SKILL_MAGIC,
                                '+', 0,
                                '%', 80,
                        },
                        {
                                SKILL_SORCERY,
                                '+', 0,
                                '%', 80,
                        },
                        {
                                SKILL_CLIMB,
                                '+', 0,
                                '+', 40,
                        },
                        {
                                SKILL_SWIM,
                                '+', 0,
                                '+', 40,
                        },
                        {
                                SKILL_SHOOT_TILL_KILL,
                                '+', 1000,
                                '+', 0,
                        },
                },
        },

        {
                "Half-Troll",
                { 4, -4, -2, -4,  3, -6 },
                -5, -8, -8, -2,  -1, 5, 20, -10,
                12,  135,
                20, 10,
                96, 10, 250, 50,
                84,  8, 225, 40,
                3,
//                0x67B, 011001111011 -> 110111100110
//		0xDE6,
//		0x67B,
		CFW+CFP+CFR+CFM+CFA+CFX+CFD+CFS,
                20,
                {
                        {
                                SKILL_BLUNT,
                                '+', 0,
                                '%', 110,
                        },
                        {
                                SKILL_HEALTH,
                                '+', 3000,
                                '%', 110,
                        },
                        /* Silly Half-Troll archers/rogues */
                        {
                                SKILL_ARCHERY,
                                '+', 0,
                                '%', 50,
                        },
                        {
                                SKILL_CRITS,
                                '+', 0,
                                '%', 80,
                        },
                        /* Not banned, but *hard* */
                        {
                                SKILL_MAGIC,
                                '+', 0,
                                '%', 50,
                        },
                        {
                                SKILL_SORCERY,
                                '+', 0,
                                '%', 50,
                        },
                        {
                                SKILL_CLIMB,
                                '+', 0,
                                '+', 40,
                        },
                        {
                                SKILL_SWIM,
                                '+', 0,
                                '+', 30,
                        },
                        {
                                SKILL_SHOOT_TILL_KILL,
                                '+', 1000,
                                '+', 0,
                        },
                },
        },

        {
                "Dunadan",
                {  1,  2,  2,  2,  3,  2 },
                4,  3,  5,  0, 3, 13, 15, 10,
                10,  170,
                50, 20,
                82, 5, 190, 20,
                78,  6, 180, 15,
                0,
//                0xFFFFFFFF,
		CFW+CFI+CFP+CFR+CFM+CFA+CFL+CFN+CFX+CFD+CFS+CFU+CFC,
                105,
                {
                        /* Dunadan makes good generalist */
                        {
                                SKILL_COMBAT,
                                '+', 0,
                                '%', 110,
                        },
                        {
                                SKILL_MAGIC,
                                '+', 0,
                                '%', 105,
                        },
                        {
                                SKILL_ARCHERY,
                                '+', 0,
                                '%', 110,
                        },
                        {
//                                SKILL_TRAINING,
                                SKILL_INTERCEPT,
                                '+', 1000,
                                '%', 110,
                        },
                        {
                                SKILL_CLIMB,
                                '+', 0,
                                '+', 40,
                        },
                        {
                                SKILL_SWIM,
                                '+', 0,
                                '+', 60,
                        },
                        {
                                SKILL_SHOOT_TILL_KILL,
                                '+', 1000,
                                '+', 0,
                        },
                },
        },

        {
                "High-Elf",
                {  1,  3, -1,  3,  1,  3 },
                4,  20, 20,  3,  3, 14, 10, 25,
                10,  250,
                100, 30,
                90, 10, 190, 20,
                82, 10, 180, 15,
                4,
//                0xF77, 101101110111 -> 111011101101
//		0xEEF,
//		0xB77,
		CFW+CFI+CFR+CFM+CFA+CFN+CFX+CFD+CFU+CFC,
                125,
                {
                        {
                                SKILL_BOW,
                                '+', 1000,
                                '%', 110,
                        },
                        {
                                SKILL_MAGIC,
                                '+', 0,
                                '%', 110,
                        },
                        {
                                SKILL_STEALTH,
                                '+', 0,
                                '%', 110,
                        },
                        {
                                SKILL_DODGE,
                                '+', 0,/*1000*/
                                '%', 110,
                        },
                        {
                                SKILL_AGILITY,
                                '+', 2000,
                                '%', 115,
                        },
                        {
                                SKILL_CALMNESS,
                                '+', 2000,
                                '%', 115,
                        },
                        {
                                SKILL_CLIMB,
                                '+', 0,
                                '+', 40,
                        },
                        {
                                SKILL_SWIM,
                                '+', 0,
                                '+', 60,
                        },
                        {
                                SKILL_SHOOT_TILL_KILL,
                                '+', 1000,
                                '+', 0,
                        },
                },
        },

        {
                "Yeek",
                {  -5, -5, -5, -5, -5, -3 },
                0,  0,  0,  0,  0,  10,  0,  0,
                7,  80, /* 8, 35 */ /* 80% for the new RPG_SERVER originally */
                14,  6,
                72,  6, 180, 25,
                66,  4, 150, 20,
                0,
//                0x7FF,
		CFW+CFI+CFP+CFR+CFM+CFA+CFL+CFN+CFX+CFD+CFS+CFU+CFC,
                50,
//                {{ 0 }},
		{
                        {
                                SKILL_CLIMB,
                                '+', 0,
                                '+', 40,
                        },
                        {
                                SKILL_SWIM,
                                '+', 0,
                                '+', 60,
                        },
                        {
                                SKILL_SHOOT_TILL_KILL,
                                '+', 1000,
                                '+', 0,
                        },
		},
        },

        {
                "Goblin",
                {  0, -1, -4,  4,  2, -5 },
                2, -3, -3,  0,  2, 8, 12, -5,
                10,  120,//increased from 115 to 125 due to great starting abilities for fighters
                11,  4,
                66,  1, 150,  5,
                62,  1, 120,  5,
                3,
//                0x673,  011001110011 -> 110011100110
//		0xCE6,
//		0xB73,
		CFW+CFR+CFM+CFA+CFN+CFX+CFD+CFS+CFU+CFC,
                70,
                {
                        /* Never ask me the reason why, I love boomerang :) */
                        /* DG - Why ? ;) */
                        {
                                SKILL_BOOMERANG,
                                '+', 1000,
                                '%', 110,
                        },
                        {
                                SKILL_STEALING,
                                '+', 0,
                                '%', 110,
                        },
                        {
                                SKILL_CLIMB,
                                '+', 0,
                                '+', 40,
                        },
                        {
                                SKILL_SWIM,
                                '+', 0,
                                '+', 50,
                        },
                        {
                                SKILL_SHOOT_TILL_KILL,
                                '+', 1000,
                                '+', 0,
                        },
                },
        },

        {
                "Ent",
                { 8, -4, +2, -4,  8, -4 },
                -4, 0, 20, -6, 5, 4, 5, -20,
                14, 320,
                255, 70,
                72, 6, 100, 25,
                66, 4, 100, 20,
                0,
//                0xD2B,  110100101011 -> 110101001011
//		0xD4B,
//		0x72B,
		CFW+CFP+CFM+CFX+CFD+CFS,
                90,
                {
			{
                                SKILL_AXE,
                                '+', 0,
                                '%', 80,
			},
			{
                                SKILL_SWORD,
                                '+', 0,
                                '%', 90,
			},
                        {
                                SKILL_HEALTH,
                                '+', 1000,
                                '%', 110,
                        },
                        {
                                SKILL_CALMNESS,
                                '+', 1000,
                                '%', 115,
                        },
                        /* Ent loves water and the Earth */
                        {
                                SKILL_EARTH,
                                '+', 0,
                                '%', 120,
                        },
                        {
                                SKILL_WATER,
                                '+', 0,
                                '%', 120,
                        },
                        /* But hates fire */
                        {
                                SKILL_FIRE,
                                '+', 0,
                                '%', 60,
                        },
                        {
                                SKILL_CLIMB,
                                '+', 0,
                                '+', 40,
                        },
                        {
                                SKILL_SWIM,
                                '+', 0,
                                '%', 0,
                        },
                        {
                                SKILL_SHOOT_TILL_KILL,
                                '+', 1000,
                                '+', 0,
                        },
                },
        },
        {
                "Draconian",	// "Dragonrider", "Thunderlord"
//                {  6,  3,  -10,  0,  5,  5 },
//		  {  6,  2,  -2,  1,  3,  5 },
//		  {  6,  2,  1,  1,  3,  5 },
		  {  4,  2,  2,  1,  3,  2 },
                0,  7,  10,  -10,  10,  10,  15,  5,
                12,  350,
                14,  6,
                180,  6, 255, 25,
                150,  4, 230, 20,
                5,
//                0xF6F,  111101101111 -> 111101101111
//		0xF6F,
		CFW+CFI+CFP+CFM+CFA+CFN+CFX+CFD+CFS+CFU+CFC,
                95,
                {
                        {
                                SKILL_POLEARM,
                                '+', 0,
                                '%', 110,
                        },
                        {
                                SKILL_DEVICE,
                                '+', 0,
                                '%', 110,
                        },
			{
                                SKILL_TCONTACT,
                                '+', 0,
                                '%', 110,
                        },
                        {
                                SKILL_CLIMB,
                                '+', 0,
                                '+', 40,
                        },
                        {
                                SKILL_SWIM,
                                '+', 0,
                                '+', 60,
                        },
                        {
                                SKILL_SHOOT_TILL_KILL,
                                '+', 1000,
                                '+', 0,
                        },

#ifdef ENABLE_DRACONIAN_TRAITS
                        {
                                SKILL_BREATH,
                                '+', 1000,
                                '+', 0,
                        },
#endif
                },
        },

#ifdef ENABLE_KOBOLD
        {
                "Kobold",
                { -1, -1,  0,  2,  2, -2 },
                10,  5,  0,  4, 15,  15, -5, 10,
                8,  115,
                11,  4,
                66,  1, 150,  5,
                62,  1, 120,  5,
                5,
		CFW+CFR+CFM+CFA+CFD+CFS+CFU+CFX, /* mh, adventurer?.. */
                120,
                {
                        {
                                SKILL_TRAPPING,
                                '+', 0,
                                '%', 110,
                        },
                        {
                                SKILL_SNEAKINESS,
                                '+', 0,
                                '%', 105,
                        },
                        {
                                SKILL_CLIMB,
                                '+', 0,
                                '+', 40,
                        },
                        {
                                SKILL_SWIM,
                                '+', 0,
                                '+', 70,
                        },
                        {
                                SKILL_SHOOT_TILL_KILL,
                                '+', 1000,
                                '+', 0,
                        },
                },
        },
#endif

        {
                "Dark-Elf",
                {  0,  2, 1,  3,  1,  -6 },
                7,  3, 6,  4, 10, 6, 15, 15,
                10,  150,
                100, 30,
                90, 10, 180, 20,
                82, 10, 180, 15,
                8,
//                0xF77, 111101110111 -> 111011101111
//		0xEEF,
//		0xF7F,
		CFW+CFI+CFP+CFR+CFM+CFA+CFN+CFX+CFD+CFS+CFU+CFC,
                115,
                {
#if 0
                        {
                                SKILL_ARCHERY,
                                '+', 1000,
                                '%', 110,
                        },
#endif
                        {
                                SKILL_BACKSTAB,
                                '+', 1000,
                                '%', 110,
                        },
                        {
                                SKILL_STEALTH,
                                '+', 0,
                                '%', 110,
                        },
                        {
                                SKILL_DODGE,
                                '+', 0,/*1000,*/
                                '%', 110,
                        },
                        {
                                SKILL_AGILITY,
                                '+', 2000,
                                '%', 110,
                        },
                        {
                                SKILL_SNEAKINESS,
                                '+', 2000,
                                '%', 110,
                        },
                        {
                                SKILL_CLIMB,
                                '+', 0,
                                '+', 40,
                        },
                        {
                                SKILL_SWIM,
                                '+', 0,
                                '+', 50,
                        },
                        {
                                SKILL_SHOOT_TILL_KILL,
                                '+', 1000,
                                '+', 0,
                        },
                },
        },

        {
                "Vampire",
                {  2,  0, -3,  -1,  0,  -6 },
                -2,  3, 20,  2,  -4, 13, 10, -10,
//                11,  240,
                11,  220,
                100, 30,
                90, 10, 180, 20,
                82, 10, 170, 15,
                15,
//                0xF77, 111101110111 -> 111011101111
//		0xEEF,
//		0x857,
		CFW+CFI+CFR+CFA+CFX+CFU+CFC,
                125,
                {
                        {
                                SKILL_BLUNT,
                                '+', 0,
                                '%', 0,
                        },
                        {
                                SKILL_DIVINATION,
                                '+', 0,
                                '%', 75,
                        },
                        {
                                SKILL_WATER,
                                '+', 0,
                                '%', 0,
                        },
                        {
                                SKILL_NATURE,
                                '+', 0,
                                '%', 0,
                        },
                        {
                                SKILL_HOFFENSE,
                                '+', 0,
				'%', 0,
			},
			{
                                SKILL_HDEFENSE,
                                '+', 0,
                                '%', 0,
                        },
                        {
                                SKILL_HCURING,
                                '+', 0,
                                '%', 0,
                        },
                        {
                                SKILL_HSUPPORT,
                                '+', 0,
                                '%', 0,
                        },
			/* Moderate bonus to Nether, being the undead... */
			{
				SKILL_R_NETH,
				'+', 800,
				'%', 120,
			},
                        {
                                SKILL_MIMIC, /* polymorph to vampire bat and maybe vampiric mist */
                                '+', 1000,
                                '%', 0,
                        },
                        {
                                SKILL_ANTIMAGIC, /* keep mimicry usable for bat form. vampires believe! for now at least... */
                                '%', 0,
                                '%', 0,
                        },
                        {
                                SKILL_MINTRUSION,
                                '+', 0,
                                '%', 110,
                        },

                        {
                                SKILL_NECROMANCY,
                                '+', 5000,
                                '%', 115,
                        },
                        {
                                SKILL_TRAUMATURGY,
                                '+', 0,
                                '%', 105,
                        },
                        {
                                SKILL_AURA_FEAR,
                                '+', 0,
                                '%', 115,
                        },
                        {
                                SKILL_AURA_SHIVER,
                                '+', 0,
                                '%', 115,
                        },
                        {
                                SKILL_AURA_DEATH,
                                '+', 0,
                                '%', 115,
                        },
                        {
                                SKILL_CLIMB,
                                '+', 0,
                                '+', 40,
                        },
                        {
                                SKILL_SWIM,
                                '+', 0,
                                '+', 40,
                        },
                        {
                                SKILL_SHOOT_TILL_KILL,
                                '+', 1000,
                                '+', 0,
                        },
                },
        },
#ifdef ENABLE_MAIA
/*
 * Player Race Information:
 *    Title,
 *    {STR,INT,WIS,DEX,CON,CHR},
 *    r_dis, r_dev, r_sav, r_stl, r_srh, r_fos, r_thn, r_thb,
 *    hitdie, exp base,
 *    Age (Base, Mod),
 *    Male (Hgt, Wgt),
 *    Female (Hgt, Wgt)
 *    infra,
 *    class-choices
 *    mana %  (<- obsolete)
 */
        {
                "Maia",
/*
Ah, the angel and demon race!
Here is the plan:
- 2 New uniques: a minor demon (Darkling) and a lesser angel (Candlebearer)
  (Maybe they do not move, do not give exp, do not attack?)
- Starts as a divine
- Level 1-20 skill tree plan:
  - Combat 1.0
    - Weap mastery 1.0
      - sword/blunt/pole/axe 0.5
      - MA 0.0
    - Magic 1.0, all children off ?
  - Sneakiness 0.5
    - Stealth 0.4
    - Stealing/Disarm 0.4
- At level 20:
  - if Darkling is killed:
    - turns into an angel:
      - Divination skill unlocked (0.0, +0.4)
      - Holy XXX skills unlocked (0.0, +0.4)
      - Nature skill unlocked (0.0, +0.4)
      - Swordsmastery skills unlocked/increased (0.0, +0.4)
      - intrinstic light radius (+1 per 4 levels)
      - Sneak/stealth skills unlocked/increased (0.0, +0.4)
      - MD skill unlocked (0.0, +0.4)
      - Udun are disabled!
XXX      - light res
XXX      - extra AC per level (+1 per level past 20)
  - if Candlebearer is killed:
    - turns into a demon:
      - Air skill unlcoked (0.0, +0.4)
      - Conveyance skill unlocked (0.0, +0.4)
      - Udun skill unlocked (0.0, +5.0)
      - Necromany skills get massive boosting! (0.0, +1.5)
      - Blunt skills get boosted (0.0, +0.4)
      - Axe skills get boosted (0.0, +0.4)
      - MA skills get boosted (0.0, +0.3)
      - Holy XXX are disabled!
XXX      - fire res
XXX      - cold susceptibility!!!! (sucker!)
XXX      - extra hp per level (+2 per level past 20)
XXX- At level 50:
XXX  - angels:
XXX    - slay_evil
XXX    - res poison
XXX    - Fly~~~
XXX    - ELEC_SHEATH
XXX  - demons:
XXX    - fire immune
XXX    - res poison
XXX    - FIRE_SHEATH

XXXTODO: A quest to transform into an angel or a demon instead of counting kills ^_^
XXXTODO: OR! Make 2 new uniques: Darkling and a Lightbearer.... 
XXX        If Darkling is killed at 20, you turn into an Angel
XXX        If lightbearer is killed at 20, you turn into a Demon
XXX        Both/neither are killed at 20: you die. Simple. 
XXXTODO: Display the message at 15, warning at 19
XXX
TODO: 3 options:
      - No new schools (use preexisting)
      - Only allow new school
      - We can lower the amount of skill points gained by this race and have a new
      school while allowing some of the current schools be learned by this race
TODO: - stuff....
      - no, really. the new school (Divine Power?), disable warriors and archers from the list
      - NO GLYPHING! NO WALL CREATIONS! NO TREE GROWAGE!
SPELLS: ({ythanks, dg)
		Angel:
			5: Levitation,
			10: Manabolt				cost 10 SP	follow manabolt curve
			20: Manablast				cost 1.5*manabolt cost		manabolt dmg curve(beam attack)
			25: Manaball				cost 2*manabolt cost		manabolt dmg curve(ball attack)
			30: Slay Evil,FA, mana regen
			35: light resistance+susp darkness, fly, no food needed?
			40: esp good, esp demon, esp undead
			45: Cloud of Power			cost =player lvl.	= playerlvl  mana+fire cloud?	dur=playerlevel/2
			50: ManaStorm, No stun			cost = playerlevel*2	dmg=(playerlevel*10)+200 area spell.
			55: Holy Wrath				cost = playerlevel*2	700 dmg all evil creature in LoS, 2.5x vs undead/demons
			60: Divine Wrath			cost = playerlevel*3	1500 dmg to all creature in LoS, irresistable. 75% dmg vs all unique, x2 vs demons/undead
			65: +1 spd per 2 level
			70: Wraith,unwraith, Divine Barrier	cost = 100%SP. all creatures summoned within barrier radius have 25% original HP. barrier radius = light radius. dur=30turn 700 turn cool down.
			75: lol. "Objection!" - Polymorph into blades 		with full equipment		Duration = 2500 turns, 3000 turns cool down.
		Demon:
			5: Fire resistance
			10: DarkBolt				same as angel's manabolt
			20: Darkball				cost = 2*darkbolt		same dmg(ball attack)
			25: FA, hp regen
			30: Darkness resistance+susp light, Fire Brand, Acid Brand,no food needed?
			35: Kill Wall, resist poison	
			40: Cloud of the End			cost = playerlevel*2 	Armageddon Cloud dmg = Playerlevel	dur=playerlevel/2
			45: increase Critial chance?
			50: Unholy Vengence, Fire Immunity	+1 bpr, Spd+ = playerlevel/ 4		(does not stack with spd pots)
			55: HP boost				4% hp boost every 2 level
			60: Rocket				dmg = (playerhp/3) + 250 rocket dmg
			65: Gate Creation, Gate Destruction	creates/destroys a speical void gate, allows players to access with >, Even out of no teleport vaults!  need an exit and entrance. cost 100% max SP. Only 2 gates allowed at once.
		        70: Soul Reaver				cost = 100% max SP, 750 dmg to all creature.  (3%+criticalchance) instant kill lvl 110 or lower, living, non-unique creatures in LoS(count as kill) (3%+critchance) chance of lowering unique's hp by 40%. 700 turn cool down.
			75: lawl. btw N aren't evil :( - Polymorph into Nether Guard 	with full equip			Duration = 2500 turns, 3000 turns cool down.
(real) spells:
(plan is to have only 1 skill and a generically named spells that have different effect depending on the caster's alignment!
level is determined runemastery style =P (player_level + skill_level)/2 (or we could set cap to 70... too much work here though i think)
level 10: 	Power bolt		A: mana bolt
					D: fire bolt-- no, nether

level 15: 	Power blast		A: light beam
					D: darkness beam-- no, nether

level 25:	Power ball		A: mana/light ball
					D: hellfire ball?-- no, nether

level 30: 	Vengence		A: mass tele_to!!!
					D: see:power staff 

level 40:	Empowerment		A: +speed (level/4)
					D: +hp: +1 at 40, +2 at 52 +3 at 55

level 50:	Intensify		A: slow los(max -10? more?, non unis), mana/time res
					D: same as +(1..10) crit ring (maxes at 60)

level 60(70): 	Power Cloud		A: mana cloud
					D: rocket cloud

level 62(74): 	Gateway			A: instant wor for everyone in party on same floor!
					D: void gate creation... on the same level only though. omghax
TODO: better generic names plx
TODO: school name: Astral Knowledge

TODO: CONE direction!!!111oneoneone~!
TODO: More usage for starlight direction too?

Random notes:
Nothing here that truly heals/buffs people (those bonus are to self only). They can get them from other schools
30.A: Meat for me! Literally. OR we can go for gathering party members on the same floor to us. Useful if they're all scattered
62.A: Activating /rec XX YY from Bree also ports every party member in Bree to XX YY :)
62.D: No idea about the amount of work required.
*/
                { 1,  3, 3,  1,  0, 2 }, //boosted int/wisdom/dex
                3, 20, 3, 0,  5, 1, 15, 5,
		11, 400,//too low == bad since you need the quest mobs
		255, 250,
                72,  16, 150, 55,
                66,  8, 130, 40,
                10,
		/* Plan is to disable warrior and archer since they do not have SP */
//                0xFFFFFFFF, //All classess for now
//		0x00000F99,
		CFP+CFI+CFR+CFM+CFL+CFN+CFX+CFD+CFS+CFU+CFC,
                125,
                {
/* The plan is to have a skill tree that is updated as the player level.
Only 70%-ify the skills that could potentially be updated when the player mutates!!
 */
			{
				SKILL_ASTRAL,
				'+', 1250,
				'+', 1250,
			},
                        {
                                SKILL_HOFFENSE,
                                '+', 0,
				'%', 70,
			},
			{
                                SKILL_HDEFENSE,
                                '+', 0,
                                '%', 70,
                        },
                        {
                                SKILL_HCURING,
                                '+', 0,
                                '%', 70,
                        },
                        {
                                SKILL_HSUPPORT,
                                '+', 0,
                                '%', 70,
                        },
			{
				SKILL_SNEAKINESS,
				'+', 0,
				'%', 110,
			},
			{
				SKILL_STEALTH,
				'+', 0,
				'%', 110,
			},
                        {
                                SKILL_NECROMANCY,
                                '+', 0,
                                '%', 70,
                        },
                        {
                                SKILL_TRAUMATURGY,
                                '+', 0,
                                '%', 70,
                        },
                        {
                                SKILL_AURA_FEAR,
                                '+', 0,
                                '%', 70,
                        },
                        {
                                SKILL_AURA_SHIVER,
                                '+', 0,
                                '%', 70,
                        },
                        {
                                SKILL_AURA_DEATH,
                                '+', 0,
                                '%', 70,
                        },
                        {
                                SKILL_CLIMB,
                                '+', 0,
                                '+', 40,
                        },
                        {
                                SKILL_SWIM,
                                '+', 0,
                                '%', 0,
                        },
                        {
                                SKILL_SHOOT_TILL_KILL,
                                '+', 1000,
                                '+', 0,
                        },
                },
        },
#endif

#if 0 // do not activate until I find a way to have a race in the server and not in the client
        {
                "Exp 626",
                {  1,  2,  -3,  1,  2,  -3 },
                4,  20, 20,  3,  3, 14, 10, 25,
                11,  150,
                14,  6,
                180,  6, 255, 25,
                150,  4, 230, 20,
                0,
                0xFFFFFFFF,
                105,
                { 0 },
        },
#endif
};

 /* Lookup for the race name */
char *special_prace_lookup[MAX_RACE] = {
/* RACE_HUMAN */ 	"Human",
/* RACE_HALF_ELF */ 	"Half-Elven",
/* RACE_ELF */ 		"Elven",
/* RACE_HOBBIT */ 	"Hobbitonian",
/* RACE_GNOME */ 	"Gnome",
/* RACE_DWARF */ 	"Dwarven",
/* RACE_HALF_ORC */ 	"Half-Orc",
/* RACE_HALF_TROLL */ 	"Half-Troll",

/* RACE_DUNADAN */ 	"Western",
/* According to Vir:
 *  Dunedain: men of the West,
 *  Dunadan:  man of the West.
 * "You can't bend in English since it's not"...
 * "dun" == west, "edain" is men of the three great houses who travelled
 *  towards the light in the west in the first age befriending the elves.
 * Yes, I got the whole history off him =)
 * Sticking with "Western" for now, then. */

/* RACE_HIGH_ELF */ 	"High-Elven",
/* RACE_YEEK */ 	"Yeek",
/* RACE_GOBLIN */ 	"Goblin",
/* RACE_ENT */ 		"Ent",
/* RACE_DRACONIAN */ 	"Draconian",
#ifdef ENABLE_KOBOLD
 /* RACE_KOBOLD*/	"Kobold",
#endif
/* RACE_DARK_ELF */ 	"Dark-Elven",
/* RACE_VAMPIRE */ 	"Vampire",
#ifdef ENABLE_MAIA
/* RACE_MAIA */		"Maia",
#endif
};

/*
 * Player Race Information:
 *    Title,
 *    {STR,INT,WIS,DEX,CON,CHR},
 *    r_dis, r_dev, r_sav, r_stl, r_srh, r_fos, r_thn, r_thb,
 *    hitdie, exp base,
 *    Age (Base, Mod),
 *    Male (Hgt, Wgt),
 *    Female (Hgt, Wgt)
 *    infra,
 *    class-choices
 *    mana%
 */


/*
 * Player Classes.
 *
 *   Title,
 *   Color,
 *   {STR,INT,WIS,DEX,CON,CHR},
 *   {STR,INT,WIS,DEX,CON,CHR} recommended minimum values,
 *   c_dis, c_dev, c_sav, c_stl, c_srh, c_fos, c_thn, c_thb,
 *   x_dis, x_dev, x_sav, x_stl, x_srh, x_fos, x_thn, x_thb,
 *   HD, Exp
 */
/* TODO: let's move them to p_info.txt */
player_class class_info[MAX_CLASS] =
{
	{
                "Warrior",
                TERM_UMBER,
		{ 5, -2, -2, 2, 2, -1},
		{ 22+100, 0, 0, 0+100, 0, 0},
		20, 18, 18, 1,  14, 2, 70, 55,
		10, 7,  10, 0,  0,  0,  45, 40,
		10, 0,//6,  10,//9, 10,
//		11, 0,
                {
                        {
                                SKILL_COMBAT,
                                '+', 3000,
                                '+', 2000,
                        },
                        {
                                SKILL_MASTERY,
                                '+', 1000,
                                '+', 1000,
                        },
                        {
                                SKILL_TECHNIQUE,
                                '+', 1000,
                                '+', 0,
                        },
#ifdef DUAL_WIELD /* warriors may too :) */
                        { /* dual-wield */
                                SKILL_DUAL,
                                '+', 1000,
                                '+', 0,
                        },
#endif
#ifdef ENABLE_STANCES /* was warrior-only, now also mimics/paladins/rangers */
                        {
                                SKILL_STANCE,
                                '+', 1000,
                                '+', 0,
                        },
#endif
                        {
                                SKILL_SWORD,
                                '+', 0,
                                '+', 800,
                        },
                        {
                                SKILL_AXE,
                                '+', 0,
                                '+', 800,
                        },
                        {
                                SKILL_BLUNT,
                                '+', 0,
                                '+', 800,
                        },
                        {
                                SKILL_POLEARM,
                                '+', 0,
                                '+', 800,
                        },
                        {
                                SKILL_BOW,
                                '+', 0,
                                '+', 350,
                        },
                        {
                                SKILL_XBOW,
                                '+', 0,
                                '+', 350,
                        },
                        {
                                SKILL_BOOMERANG,
                                '+', 0,
                                '+', 350,
                        },
                        {
                                SKILL_SLING,
                                '+', 0,
                                '+', 300,
                        },
                        {
                                /* let's keep it low for now - offbalancing */
                                SKILL_MARTIAL_ARTS,
                                '+', 0,
                                '+', 700,
                        },

                        {
                                SKILL_DEVICE,
                                '+', 1000,
                                '+', 600,
                        },
                        {
                                SKILL_SNEAKINESS,
                                '+', 1000,
                                '+', 800,//900,
                        },
                        {
                                SKILL_STEALTH,
                                '+', 1000,
                                '+', 600,
                        },
                        {
                                SKILL_DISARM,
                                '+', 1000,
                                '+', 900,
                        },
                        {
                                SKILL_DODGE,
                                '+', 0,/*1000*/
                                '+', 800,
                        },

			/* Necromancy for this class - experimental */
                        {
                                SKILL_NECROMANCY,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_TRAUMATURGY,
                                '%', 0,
                                '%', 0,
                        },
                        {
                                SKILL_AURA_FEAR,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_AURA_SHIVER,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_AURA_DEATH,
                                '+', 0,
                                '+', 1000,
                        },

                        {
                                SKILL_ANTIMAGIC,
                                '+', 0,
                                '+', 500,//700
                        },
						/* Health tree */
                        {
                                SKILL_HEALTH,
                                '+', 2000,
                                '+', 1000,
                        },
                        {
                                SKILL_SWIM,
                                '+', 0,
                                '%', 120,
                        },
                        {
                                SKILL_DIG,
                                '+', 1000,
                                '+', 1200,
                        },
                        {
                                SKILL_INTERCEPT,
                                '+', 1000,
                                '+', 800,
                        },
                }
	},

	{
                "Istar",
                TERM_RED,
		{-5, 3, 0, 1, -2, 1},
		{0, 0+100, 0, 0, 0, 0},
		30, 36, 30, 2,  16, 20, 34, 20,
		7,  13, 9,  0,  0,  0,  15, 15,
		0, 35,//0,30
//		3, 35,
                {
                        {
                                SKILL_COMBAT,
                                '+', 0,
                                '+', 300,
                        },
                        {
                                SKILL_MASTERY,
                                '+', 0,
                                '+', 150,
                        },
                        {
                                SKILL_MAGIC,
                                '+', 4000,	/* 6000 */
                                '+', 1000,
                        },
                        {
                                SKILL_DEVICE,
                                '+', 1000,
                                '+', 1200,
                        },
                        {
                                SKILL_SNEAKINESS,
                                '+', 1000,
                                '+', 500,//700,
                        },
                        {
                                SKILL_STEALTH,
                                '+', 0,
                                '+', 600,
                        },
                        {
                                SKILL_DODGE,
                                '+', 0,
                                '+', 300,
                        },
						/* Health tree */
                        {
                                SKILL_HEALTH,
                                '+', 0,
                                '+', 800,
                        },
                        {
                                SKILL_CALMNESS,
                                '+', 0,
                                '+', 800,
                        },
                        {
                                SKILL_DIG,
                                '+', 0,
                                '+', 700,
                        },

                        {
                                SKILL_SORCERY,
                                '+', 0,
/*				'+', 500,//was 700 */
/*				'+', 170,  1..9schools->schools,10..12->sorc */
/*				'+', 185,  49*5.5 skill points -> sorcery ~maxed. */
				'+', 205,  /* 49*5 -> maxed at 50 */
                        },
                        {
                                SKILL_SPELL,
                                '+', 0,
                                '+', 600,
                        },
                        {
                                SKILL_MANA,
                                '+', 1000,	/* Allow to cast Manathrust */
                                '+', 1900,
                        },
                        {
                                SKILL_FIRE,
                                '+', 0,
                                '+', 1600,
                        },
                        {
                                SKILL_AIR,
                                '+', 0,
                                '+', 1600,
                        },
                        {
                                SKILL_EARTH,
                                '+', 0,
                                '+', 1600,
                        },
                        {
                                SKILL_WATER,
                                '+', 0,
                                '+', 1600,
                        },
                        {
                                SKILL_NATURE,
                                '+', 0,
                                '+', 1600,
                        },
                        {
                                SKILL_DIVINATION,
                                '+', 0,
                                '+', 1600,
                        },
                        {
                                SKILL_CONVEYANCE,
                                '+', 0,
                                '+', 1600,
                        },
                        {
                                SKILL_META,
                                '+', 0,
                                '+', 1600,
                        },
                        {
                                SKILL_MIND,
                                '+', 0,
                                '+', 1600,
                        },
                        {
                                SKILL_TEMPORAL,
                                '+', 0,
                                '+', 1600,
                        },
                        {
                                SKILL_UDUN,
                                '+', 0,
                                '+', 1600,
                        },

			/* Necromancy for this class - experimental */
                        {
                                SKILL_NECROMANCY,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_TRAUMATURGY,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_AURA_FEAR,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_AURA_SHIVER,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_AURA_DEATH,
                                '+', 0,
                                '+', 1000,
                        },
                }
	},

	{
		"Priest",
                TERM_GREEN,
                {-1, -3, 3, -1, 0, 2},
#if 0 /* disabled recommendations for STR/DEX because STR cannot even be reached by dwarven priests.. */
		{19, 0, 0+100, 10, 0, 0},
#else
		{0, 0, 0+100, 0, 0, 0},
#endif
		25, 25, 32, 2,  16, 8, 48, 35,
		7,  10, 12, 0,  0,  0, 20, 15,
		4, 20, //2, 20,//4,20
//		7, 20,
                {
                        {
                                SKILL_COMBAT,
                                '+', 0,
                                '+', 750,//x1.5
                        },
                        {
                                SKILL_MASTERY,
                                '+', 0,
                                '+', 400,//800
                        },
						/* let's give them some skills for non-swords */
                        {
                                SKILL_SWORD,
                                '+', 0,
                                '+', 500,
                        },
                        {
                                SKILL_BLUNT,
                                '+', 0,
                                '+', 600,
                        },
                        {
                                SKILL_MARTIAL_ARTS,
                                '+', 0,
                                '+', 500,//450
                        },
                        {
                                SKILL_MAGIC,
                                '+', 2000,
                                '+', 900,
                        },
                        {
                                SKILL_SPELL,
                                '+', 0,
                                '+', 500,
                        },
/*                        {
                                SKILL_DIVINATION,
                                '+', 1000,
                                '+', 500,
                        },
                        {
                                SKILL_CONVEYANCE,
                                '+', 0,
                                '+', 900,
                        },,*/
                        {
                                SKILL_HOFFENSE,
                                '+', 0,
                                '+', 1500,
                        },
                        {
                                SKILL_HDEFENSE,
                                '+', 1000, /* be able to use the startup eq spellbook of blessing */
                                '+', 1500,
                        },
                        {
                                SKILL_HCURING,
                                '+', 1000,
                                '+', 1500,
                        },
                        {
                                SKILL_HSUPPORT,
                                '+', 0,
                                '+', 1500,
                        },
                        {
                                SKILL_DEVICE,
                                '+', 1000,
                                '+', 1100,
                        },
                        {
                                SKILL_SNEAKINESS,
                                '+', 1000,
                                '+', 600,//770,
                        },
                        {
                                SKILL_STEALTH,
                                '+', 0,
                                '+', 500,
                        },
                        {
                                SKILL_DODGE,
                                '+', 0,
                                '+', 450,
                        },
						/* Health tree */
                        {
                                SKILL_HEALTH,
                                '+', 1000,
                                '+', 1000,
                        },
                        {
                                SKILL_DIG,
                                '+', 0,
                                '+', 700,
                        },
                        {
                                SKILL_CALMNESS,
                                '+', 0,
                                '+', 900,
                        },
                        {
                                SKILL_INTERCEPT,
                                '+', 1000,
                                '+', 500,//400
                        },
                }
	},

	{
                "Rogue",
                TERM_BLUE,
		{ 2, 1, -2, 3, 1, -1},
		{15, 0, 0, 19+100, 0, 0},
		45, 28, 28, 5, 32, 24, 60, 66,
		15, 10, 10, 0, 10, 10, 40, 40,// ..0,0,40,30
		5, 15, //3, 25,//5, 25
//		8, 25,
                {
                        {
                                SKILL_COMBAT,
                                '+', 1000,
                                '+', 1200,
                        },
                        {
                                SKILL_MASTERY,
                                '+', 1000,
                                '+', 700,//650
                        },
                        {
                                SKILL_TECHNIQUE,
                                '+', 1000,
                                '+', 0,
                        },
#ifdef DUAL_WIELD
                        { /* dual-wield */
                                SKILL_DUAL,
                                '+', 1000,
                                '+', 0,
                        },
#endif
                        {
                                SKILL_SWORD,
                                '+', 0,
                                '+', 600,
                        },
                        {
                                SKILL_CRITS,
                                '+', 0,
                                '+', 900,
                        },
                        {
                                SKILL_BOW,
                                '+', 0,
                                '+', 350,
                        },
                        {
                                SKILL_XBOW,
                                '+', 0,
                                '+', 350,
                        },
                        {
                                SKILL_BOOMERANG,
                                '+', 0,
                                '+', 500,
                        },
                        {
                                SKILL_SLING,
                                '+', 0,
                                '+', 450,
                        },
                        {
                                SKILL_MARTIAL_ARTS,
                                '+', 0,
                                '+', 500,
                        },
                        {
                                SKILL_MAGIC,
                                '+', 1000,
                                '+', 500,
                        },
						/* They can be changed */
                        {
                                SKILL_CONVEYANCE,
                                '+', 0,
                                '+', 750,
                        },
                        {
                                SKILL_DIVINATION,
                                '+', 0,
                                '+', 750,
                        },
                        {
                                SKILL_AIR,
                                '+', 0,
                                '+', 750,
                        },
                        {
                                SKILL_DEVICE,
                                '+', 1000,
                                '+', 1000,
                        },

			/* Necromancy for this class - experimental */
                        {
                                SKILL_NECROMANCY,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_TRAUMATURGY,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_AURA_FEAR,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_AURA_SHIVER,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_AURA_DEATH,
                                '+', 0,
                                '+', 1000,
                        },

                        {
                                SKILL_SNEAKINESS,
                                '+', 1000,
                                '+', 800,//1200,
                        },
                        {
                                SKILL_STEALTH,
                                '+', 1000,
                                '+', 700,
                        },
                        {
                                SKILL_DISARM,
                                '+', 1000,
                                '+', 1200,
                        },
                        {
                                SKILL_TRAPPING,
                                '+', 1000,
                                '+', 1000,
                        },
                        {
                                SKILL_STEALING,
                                '+', 1000,
                                '+', 1000,
                        },
                        {
                                SKILL_BACKSTAB,
                                '+', 1000,
                                '+', 1000,
                        },
                        {
                                SKILL_DODGE,
                                '+', 1000,
                                '+', 900,
                        },
						/* Health tree */
                        {
                                SKILL_HEALTH,
                                '+', 1000,
                                '+', 1000,
                        },
                        {
                                SKILL_AGILITY,
                                '+', 1000,
                                '+', 500,
                        },
                        {
                                SKILL_CALMNESS,
                                '+', 0,
//                                '+', 600,
                                '+', 800,
                        },
                        {
                                SKILL_SWIM,
                                '+', 0,
                                '%', 120,
                        },
                        {
                                SKILL_DIG,
                                '+', 0,
                                '+', 1100,
                        },
                        {
                                SKILL_INTERCEPT,
                                '+', 1000,
                                '+', 900,
                        },
                }
        },

        {
                "Mimic",
                 TERM_L_WHITE, //confusing
//		 TERM_ORANGE, <- more confusing since they're supposed to use a monster form
		{ 1, 0, 0, 1, 1, -4},
		{19+100, 0, 0, 10+100, 0, 0},//21,19
		25, 34, 28, 1, 18, 18, 60, 46,
	         9, 10, 10, 0,  0,  0, 40, 25,
		6, 30,//3, 40,//4, 25
//		8, 40,
                {
                        {
                                SKILL_COMBAT,
                                '+', 3000,
                                '+', 1600,
                        },
                        {
                                SKILL_MASTERY,
                                '+', 1000,
                                '+', 800,//750
                        },
                        {
                                SKILL_TECHNIQUE,
                                '+', 1000,
                                '+', 0,
                        },
#ifdef ENABLE_STANCES
                        {
                                SKILL_STANCE,
                                '+', 1000,
                                '+', 0,
                        },
#endif
                        {
                                SKILL_SWORD,
                                '+', 0,
                                '+', 630,
                        },
                        {
                                SKILL_AXE,
                                '+', 0,
                                '+', 630,
                        },
                        {
                                SKILL_BLUNT,
                                '+', 0,
                                '+', 630,
                        },
                        {
                                SKILL_POLEARM,
                                '+', 0,
                                '+', 630,
                        },
                        {
                                SKILL_BOW,
                                '+', 0,
                                '+', 250,
                        },
                        {
                                SKILL_XBOW,
                                '+', 0,
                                '+', 250,
                        },
                        {
                                SKILL_SLING,
                                '+', 0,
                                '+', 350,
                        },
                        {
                                SKILL_BOOMERANG,
                                '+', 0,
                                '+', 350,
                        },
                        {
                                SKILL_MARTIAL_ARTS,
                                '+', 0,
                                '+', 550,
                        },
                        {
                                SKILL_MAGIC,
                                '+', 1000,
                                '+', 700,
                        },
                        {
                                SKILL_MIMIC,
                                '+', 1000,
                                '+', 900,
                        },
                        {
                                SKILL_DEVICE,
                                '+', 1000,
                                '+', 800,
                        },

			/* Necromancy for this class - experimental */
                        {
                                SKILL_NECROMANCY,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_TRAUMATURGY,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_AURA_FEAR,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_AURA_SHIVER,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_AURA_DEATH,
                                '+', 0,
                                '+', 1000,
                        },

                        {
                                SKILL_SNEAKINESS,
                                '+', 0,
                                '+', 650,//800,
                        },
                        {
                                SKILL_STEALTH,
                                '+', 1000,
                                '+', 500,
                        },
                        {
                                SKILL_DISARM,
                                '+', 0,
                                '+', 500,
                        },
                        {
                                SKILL_DODGE,
                                '+', 0,
                                '+', 500,
                        },
                        {
                                SKILL_INTERCEPT,
                                '+', 0,
                                '+', 600,
                        },
			/* Health tree */
                        {
                                SKILL_HEALTH,
                                '+', 1000,
                                '+', 900,
                        },
                        {
                                SKILL_DIG,
                                '+', 0,
                                '+', 1200,
                        },
						/* Misc tree */
                        {
                                SKILL_CALMNESS,
                                '+', 0,
                                '+', 600,
                        },
                }
	},

	{
                "Archer",
                TERM_ORANGE,
		{ 1, 0, 2, 3, 1, -1},
		{0, 0, 0, 18+100, 0, 0},
		30, 22, 28, 2,  24, 20, 56, 72,
		8,  7, 10, 0,  0,  0,  30, 50,
		5, 10,//3, 15,//5, 15
//		8, 15,
                {
                        {
                                SKILL_COMBAT,
                                '+', 1000,
                                '+', 1700,//buffed from 1300
                        },
                        {
                                SKILL_MASTERY,
                                '+', 1000,
                                '+', 600,
                        },
                        {
                                SKILL_SWORD,
                                '+', 0,
                                '+', 400,
                        },
                        {
                                SKILL_AXE,
                                '+', 0,
                                '+', 400,
                        },
                        {
                                SKILL_BLUNT,
                                '+', 0,
                                '+', 400,
                        },
                        {
                                SKILL_POLEARM,
                                '+', 0,
                                '+', 400,
                        },
                        {
                                SKILL_ARCHERY,
                                '+', 2000,
                                '+', 1000,
                        },
                        {
                                SKILL_SLING,
                                '+', 0,
                                '+', 800,
                        },
                        {
                                SKILL_BOW,
                                '+', 1000,
                                '+', 850,
                        },
                        {
                                SKILL_XBOW,
                                '+', 0,
                                '+', 800,
                        },
                        {
                                SKILL_BOOMERANG,
                                '+', 0,
                                '+', 700,
                        },
                        {
                                SKILL_DEVICE,
                                '+', 1000,
                                '+', 800,
                        },

			/* Necromancy for this class - experimental */
                        {
                                SKILL_NECROMANCY,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_TRAUMATURGY,
                                '%', 0,
                                '%', 0,
                        },
                        {
                                SKILL_AURA_FEAR,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_AURA_SHIVER,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_AURA_DEATH,
                                '+', 0,
                                '+', 1000,
                        },

                        {
                                SKILL_SNEAKINESS,
                                '+', 1000,
                                '+', 600,//600,
                        },
                        {
                                SKILL_STEALTH,
                                '+', 1000,
                                '+', 600,
                        },
                        {
                                SKILL_DISARM,
                                '+', 500,
                                '+', 500,
                        },
                        {
                                SKILL_DODGE,
                                '+', 0,/*1000*/
                                '+', 700, /*500, but motivating light armour hereby*/
                        },
                        {
                                SKILL_ANTIMAGIC,
                                '+', 0,
                                '+', 350,//300
                        },
						/* Health tree */
                        {
                                SKILL_HEALTH,
                                '+', 1000,
                                '+', 1000,
                        },
                        {
                                SKILL_DIG,
                                '+', 0,
                                '+', 900,
                        },
                        {
                                SKILL_CALMNESS,
                                '+', 0,
                                '+', 900,
                        },
                }
	},

	{
                "Paladin",
                TERM_YELLOW,
		{ 3, -3, 1, 0, 2, 2},
		{20+100, 0, 0+100, 10, 0, 0},
/*   c_dis, c_dev, c_sav, c_stl, c_srh, c_fos, c_thn, c_thb,
 *   x_dis, x_dev, x_sav, x_stl, x_srh, x_fos, x_thn, x_thb,
 *   HD, Exp*/
		10, 21, 54, 1,  13, 16, 60, 40, //was c_thb 29
		2, 8,  10, 0,  0,  2,  35, 10,
		8, 30,//5, 30,//7,30
//		10, 30,
                {
                        {
                                SKILL_COMBAT,
                                '+', 2700,
                                '+', 1400,//nerfed from 1700
                        },
                        {
                                SKILL_MASTERY,
                                '+', 1800,
                                '+', 900,
                        },
                        {
                                SKILL_TECHNIQUE,
                                '+', 1000,
                                '+', 0,
                        },
#ifdef ENABLE_STANCES
                        {
                                SKILL_STANCE,
                                '+', 1000,
                                '+', 0,
                        },
#endif
                        {
                                SKILL_SWORD,
                                '+', 0,
                                '+', 750,
                        },
                        {
                                SKILL_AXE,
                                '+', 0,
                                '+', 700,
                        },
                        {
                                SKILL_BLUNT,
                                '+', 0,
                                '+', 800,
                        },
                        {
                                SKILL_POLEARM,
                                '+', 0,
                                '+', 750,
                        },
                        {
                                SKILL_BOW,
                                '+', 0,
                                '+', 300,
                        },
                        {
                                SKILL_XBOW,
                                '+', 0,
                                '+', 300,
                        },
                        {
                                /* let's keep it low for now - offbalancing */
                                SKILL_MARTIAL_ARTS,
                                '+', 0,
                                '+', 500,
                        },

                        {
                                SKILL_MAGIC,
                                '+', 1000,
                                '+', 800,
                        },
                        {
                                SKILL_SPELL,
                                '+', 0,
                                '+', 350,
                        },
/*                        {
                                SKILL_DIVINATION,
                                '+', 1000,
                                '+', 900,
                        },
                        {
                                SKILL_CONVEYANCE,
                                '+', 0,
                                '+', 700,
                        },*/
                        {
                                SKILL_HOFFENSE,
                                '+', 0,
                                '+', 800,
                        },
                        {
                                SKILL_HDEFENSE,
                                '+', 1000,
                                '+', 800,
                        },
                        {
                                SKILL_HCURING,
                                '+', 0,
                                '+', 800,
                        },
                        {
                                SKILL_HSUPPORT,
                                '+', 0,
                                '+', 800,
                        },

                        {
                                SKILL_DEVICE,
                                '+', 1000,
                                '+', 1000,
                        },
                        {
                                SKILL_SNEAKINESS,
                                '+', 1000,
                                '+', 500, //650,
                        },
                        {
                                SKILL_DISARM,
                                '+', 1000,
                                '+', 600,
                        },
                        {
                                SKILL_DODGE,
                                '+', 0,/*1000*/
                                '+', 600,
                        },
                        {
                                SKILL_STEALTH,
                                '+', 0,
                                '+', 500,
                        },

					/* Health tree */
                        {
                                SKILL_HEALTH,
                                '+', 2000,
                                '+', 1000,
                        },
                        {
                                SKILL_DIG,
                                '+', 1000,
                                '+', 700,
                        },
                        {
                                SKILL_CALMNESS,
                                '+', 0,
                                '+', 600,
                        },
                        {
                                SKILL_INTERCEPT,
                                '+', 1000,
                                '+', 800,
                        },
                }
	},

	{
                "Ranger",
                TERM_L_UMBER,
		{ 2, 2, -1, 1, 2, 0},
		{19+100, 0+100, 0, 10+100, 0, 0},//21,19
/*   c_dis, c_dev, c_sav, c_stl, c_srh, c_fos, c_thn, c_thb,
 *   x_dis, x_dev, x_sav, x_stl, x_srh, x_fos, x_thn, x_thb,
 *   HD, Exp*/
		34, 32, 30, 5, 30, 30, 50, 60,
		10, 10, 10, 0, 15,  5, 30, 45,
		7, 35,//4, 35,//6, 35
//		9, 35,
                {
                        {
                                SKILL_COMBAT,
                                '+', 1500,
                                '+', 1000,//nerfed from 1300
                        },
                        {
                                SKILL_MASTERY,
                                '+', 1000,
                                '+', 800,//700
                        },
                        {
                                SKILL_TECHNIQUE,
                                '+', 1000,
                                '+', 0,
                        },
#ifdef DUAL_WIELD /* rangers get an exception for now. hoping it'll balance out with giving them stances as well! */
                        { /* dual-wield */
                                SKILL_DUAL,
                                '+', 1000,
                                '+', 0,
                        },
#endif
#ifdef ENABLE_STANCES
                        {
                                SKILL_STANCE,
                                '+', 1000,
                                '+', 0,
                        },
#endif
                        {
                                SKILL_SWORD,
                                '+', 0,
                                '+', 700,
                        },
                        {
                                SKILL_AXE,
                                '+', 0,
                                '+', 700,
                        },
                        {
                                SKILL_BLUNT,
                                '+', 0,
                                '+', 700,
                        },
                        {
                                SKILL_POLEARM,
                                '+', 0,
                                '+', 700,
                        },
#if 1 /* allowed in combination with SKF1_MAX_10 restriction */
                        {
                                SKILL_ARCHERY,
                                '+', 1000,
                                '+', 700,//500
                        },
#endif
                        {
                                SKILL_SLING,
                                '+', 0,
                                '+', 450,//350
                        },
                        {
                                SKILL_BOW,
                                '+', 1000,
                                '+', 450,//350
                        },
                        {
                                SKILL_XBOW,
                                '+', 0,
                                '+', 450,//350
                        },
                        {
                                SKILL_BOOMERANG,
                                '+', 0,
                                '+', 400,
                        },
                        {
                                /* let's keep it low for now - offbalancing */
                                SKILL_MARTIAL_ARTS,
                                '+', 0,
                                '+', 500,
                        },
                        {
                                SKILL_MAGIC,
                                '+', 1000,
                                '+', 700,
                        },
                        {
                                SKILL_SPELL,
                                '+', 0,
                                '+', 450,
                        },
                        {
                                SKILL_MANA,
                                '+', 1000,	/* Allow to cast Manathrust */
                                '+', 700,//was 600 hmm
                        },
                        {
                                SKILL_FIRE,
                                '+', 0,
                                '+', 900,
                        },
                        {
                                SKILL_AIR,
                                '+', 0,
                                '+', 900,
                        },
                        {
                                SKILL_EARTH,
                                '+', 0,
                                '+', 900,
                        },
                        {
                                SKILL_WATER,
                                '+', 0,
                                '+', 900,
                        },
                        {
                                SKILL_NATURE,
                                '+', 0,
                                '+', 900,
                        },
                        {
                                SKILL_DIVINATION,
                                '+', 0,
                                '+', 800,
                        },
                        {
                                SKILL_CONVEYANCE,
                                '+', 0,
                                '+', 900,
                        },
                        {
                                SKILL_META,
                                '+', 0,
                                '+', 800,
                        },
                        {
                                SKILL_MIND,
                                '+', 0,
                                '+', 800,
                        },
#if 1
                        {
                                SKILL_TEMPORAL,
                                '+', 0,
                                '+', 700,//600,//800
                        },
#endif
                        {
                                SKILL_DEVICE,
                                '+', 1000,
                                '+', 1100,
                        },
                        {
                                SKILL_SNEAKINESS,
                                '+', 1000,
                                '+', 750,//900,
                        },
                        {
                                SKILL_DISARM,
                                '+', 1000,
                                '+', 900,
                        },
                        {
                                SKILL_DODGE,
                                '+', 0,/*1000*/
                                '+', 700,
                        },
                        {
                                SKILL_STEALTH,
                                '+', 0,
                                '+', 600,
                        },
                        {
                                SKILL_TRAPPING,
                                '+', 1000,
                                '+', 1100,
                        },

					/* Health tree */
                        {
                                SKILL_HEALTH,
                                '+', 2000,
                                '+', 1000,
                        },
                        {
                                SKILL_SWIM,
                                '+', 0,
                                '%', 120,
                        },
                        {
                                SKILL_DIG,
                                '+', 1000,
                                '+', 1200,
                        },
                        {
                                SKILL_CALMNESS,
                                '+', 0,
                                '+', 700,
                        },
                        {
                                SKILL_INTERCEPT,
                                '+', 1000,
                                '+', 800,
                        },
                }
	},

	{
                "Adventurer",
                TERM_VIOLET,
		{ 0, 0, 0, 0, 0, 0},
		{19, 0, 0, 10, 0, 0},//20,10
		30, 22, 20, 3,  15, 15, 50, 50,
		10, 10,  10, 0,  5,  5,  25, 25,//..,0,0,25,25
		6, 25, //3,  0,//5,0,
//		8, 10,
                {
                        /* Combat tree */
                        {
                                SKILL_COMBAT,
                                '+', 1000,
                                '+', 900,
                        },
                        {
                                SKILL_MASTERY,
                                '+', 0,//1000,
                                '+', 600,
                        },
                        {
                                SKILL_TECHNIQUE,
                                '+', 1000,
                                '+', 0,
                        },
                        {
                                SKILL_SWORD,
                                '+', 0,
                                '+', 550,
                        },
                        {
                                SKILL_AXE,
                                '+', 0,
                                '+', 600,
                        },
                        {
                                SKILL_BLUNT,
                                '+', 0,
                                '+', 600,
                        },
                        {
                                SKILL_POLEARM,
                                '+', 0,
                                '+', 500,
                        },
                        {
                                SKILL_SLING,
                                '+', 1000,
                                '+', 350,
                        },
                        {
                                SKILL_BOW,
                                '+', 0,
                                '+', 350,
                        },
                        {
                                SKILL_XBOW,
                                '+', 0,
                                '+', 350,
                        },
                        {
                                SKILL_BOOMERANG,
                                '+', 1000,
                                '+', 500,
                        },
                        {
                                /* let's keep it low for now - offbalancing */
                                SKILL_MARTIAL_ARTS,
                                '+', 0,
//                                '+', 450,
                                '+', 500,
                        },

                        /* Magic tree */
                        {
                                SKILL_MAGIC,
                                '+', 0,//2000,
                                '+', 600,
                        },
                        {
                                SKILL_CONVEYANCE,
                                '+', 0,//1000,
                                '+', 650,
                        },
                        {
                                SKILL_DEVICE,
                                '+', 1000,
                                '+', 1100,
                        },
                        {
                                SKILL_SPELL,
                                '+', 0,
                                '+', 350,	/* reduced from 500, after
						sorcery & mimicry got raised,
						to avoid adv becoming best sorc */
                        },
                        {
                                SKILL_MANA,
                                '+', 0, //1000,
                                '+', 500,//600, //500
                        },
                        {
                                SKILL_FIRE,
                                '+', 0,
                                '+', 600,//700, //600..
                        },
                        {
                                SKILL_AIR,
                                '+', 0,
                                '+', 700,
                        },
                        {
                                SKILL_EARTH,
                                '+', 0,
                                '+', 700,
                        },
                        {
                                SKILL_WATER,
                                '+', 0,
                                '+', 700,
                        },
                        {
                                SKILL_NATURE,
                                '+', 0, //1000,
                                '+', 700,
                        },
                        {
                                SKILL_DIVINATION,
                                '+', 0,
                                '+', 500,//600, //500
                        },
                        {
                                SKILL_META,
                                '+', 0,
                                '+', 300,
                        },
                        {
                                SKILL_MIND,
                                '+', 0,
                                '+', 500,//600, //500
                        },
#if 1
                        {
                                SKILL_TEMPORAL,
                                '+', 0,
                                '+', 400,//500, //400
                        },
#endif
                        {
                                SKILL_HOFFENSE,
                                '+', 0,
				'+', 500,//600, //500
			},
			{
                                SKILL_HDEFENSE,
                                '+', 0,
                                '+', 600,
                        },
                        {
                                SKILL_HCURING,
                                '+', 0,
                                '+', 600,
                        },
                        {
                                SKILL_HSUPPORT,
                                '+', 0,
                                '+', 600,
                        },
#if 1
			{
				SKILL_DRUID_ARCANE,
				'+', 0, '+', 500, //was formerly 300 for SKILL_DRUID (combined skill)
			},
	                {
	                	SKILL_DRUID_PHYSICAL,
	                	'+', 0, '+', 500,
	                },
#else
			{
				SKILL_DRUID,
				'+', 0, '+', 300,
			},
#endif
                        {
                                SKILL_PPOWER,
                                '+', 0,
				'+', 500,
			},
			{
                                SKILL_TCONTACT,
                                '+', 0,
                                '+', 500,
                        },
                        {
                                SKILL_MINTRUSION,
                                '+', 0,
                                '+', 500,
                        },

			{
				SKILL_R_LITE,
				'+', 0,
				'+', 500,
			},
			{
				SKILL_R_DARK,
				'+', 0,
				'+', 500,
			},
			{
				SKILL_R_NEXU,
				'+', 0,
				'+', 500,
			},
			{
				SKILL_R_NETH,
				'+', 0,
				'+', 500,
			},
			{
				SKILL_R_CHAO,
				'+', 0,
				'+', 500,
			},
			{
				SKILL_R_MANA,
				'+', 0,
				'+', 500,
			},
                        {
                                SKILL_MIMIC,
                                '+', 0,
                                '+', 400,	/* 300 was 'safer' */
                        },

                        /* Sneakiness tree */
                        {
                                SKILL_SNEAKINESS,
                                '+', 1000,
                                '+', 800,//700
                        },
                        {
                                SKILL_DISARM,
                                '+', 1000,
                                '+', 800,//700,
                        },
                        {
                                SKILL_TRAPPING,
                                '+', 1000,//0,
                                '+', 900,//600,
                        },
                        {
                                SKILL_STEALTH,
                                '+', 1000,
                                '+', 600,
                        },
                        {
                                SKILL_STEALING,
                                '+', 0,
                                '+', 600,
                        },
                        {
                                SKILL_DODGE,
                                '+', 0,
                                '+', 600,
                        },

                        /* Necromancy tree */
                        {
                                SKILL_NECROMANCY,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_TRAUMATURGY,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_AURA_FEAR,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_AURA_SHIVER,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_AURA_DEATH,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_ANTIMAGIC,
                                '+', 0,
                                '+', 500,
                        },
                        /* Health tree */
                        {
                                SKILL_HEALTH,
                                '+', 1000,
                                '+', 1100,
                        },
                        {
                                SKILL_SWIM,
                                '+', 0,
                                '%', 140,
                        },
                        {
                                SKILL_DIG,
                                '+', 1000,
                                '+', 1400,
                        },
						/* Misc tree */
                        {
                                SKILL_CALMNESS,
                                '+', 0,
                                '+', 700,
                        },
                        {
                                SKILL_INTERCEPT,
                                '+', 0,
                                '+', 700,
                        },

                }
	},

	{
                "Druid",	/* by the_sandman -- w00t w00t -- a shapechanger+magical class */
                TERM_L_GREEN,
		{ 1, 0, 2, -2, -2, 1},
		{0, 0, 0+100, 0, 0, 0},
/*   c_dis, c_dev, c_sav, c_stl, c_srh, c_fos, c_thn, c_thb,
 *   x_dis, x_dev, x_sav, x_stl, x_srh, x_fos, x_thn, x_thb,
 *   HD, Exp*/
		30, 35, 30, 4, 25, 25, 50, 44,
		8, 11, 10, 0, 10,  5, 20, 25,
		5, 40,//5, 50
                {
                        {
                                SKILL_COMBAT,
                                '+', 1000,
                                '+', 1000,//nerfed from 1300
                        },
                        {
                                SKILL_TECHNIQUE,
                                '+', 1000,
                                '+', 0,
                        },
                        {
                                SKILL_SLING,
                                '+', 0,
                                '+', 300,
                        },
                        {
                                SKILL_BOW,
                                '+', 0,
                                '+', 250,
                        },
                        {
                                SKILL_XBOW,
                                '+', 0,
                                '+', 250,
                        },
                        {
                                SKILL_BOOMERANG,
                                '+', 0,
                                '+', 350,
                        },
                        {
                                SKILL_MARTIAL_ARTS,
                                '+', 1000, /* make newbies' lives easier */
                                '+', 650,
                        },
                        /* Added nullifying of interception here, since some newbie
                           trained it as a human druid (mad waste of points) */
                        {
                                SKILL_INTERCEPT,
                                '%', 0,
                                '%', 0,
                        },
                        {
                                SKILL_MAGIC,
                                '+', 1000,
                                '+', 1000,
                        },
                        {
                                SKILL_AIR,
                                '+', 0,
                                '+', 1000, //900,
                        },
                        {
                                SKILL_EARTH,
                                '+', 0,
                                '+', 1000, //900,
                        },
                        {
                                SKILL_WATER,
                                '+', 0,
                                '+', 1000, //900,
                        },
                        {
                                SKILL_NATURE,
                                '+', 0,
                                '+', 1100, //900,
                        },
                        {
                            SKILL_DRUID_ARCANE,
                            '+', 1000, '+', 1200, //1500,
                        },
                        {
                            SKILL_DRUID_PHYSICAL,
                            '+', 1000, '+', 1200, //1500,
                        },
                        {
                                SKILL_MIMIC,
                                '+', 1000,
                                '+', 0,
                        },
                        {
                                SKILL_DEVICE,
                                '+', 1000,
                                '+', 1100,
                        },
                        {
                                SKILL_SNEAKINESS,
                                '+', 1000,
                                '+', 600,//750,
                        },
                        {
                                SKILL_DISARM,
                                '+', 0,/*1000*/
                                '+', 600,
                        },
                        {
                                SKILL_DODGE,
                                '+', 0,/*1000*/
                                '+', 500,
                        },
                        {
                                SKILL_STEALTH,
                                '+', 0,
                                '+', 600,
                        },
                        {
                                SKILL_CALMNESS,
                                '+', 0,
                                '+', 800,
                        },
			/* Health tree */
                        {
                                SKILL_HEALTH,
                                '+', 2000,
                                '+', 1100,
                        },
                        {
                                SKILL_SWIM,
                                '+', 0,
                                '%', 120,
                        },
                        {
                                SKILL_DIG,
                                '+', 1000,
                                '+', 1200,
                        },
                }
	},

	{
                "Shaman", /* by C. Blue -- Minor shapechange (restrictions), Necromancy/Praying/Magic */
                TERM_L_RED,
		{ 0, 1, 2, -2, 0, 0},
		{0, 0, 0, 0, 0, 0},
/*   c_dis, c_dev, c_sav, c_stl, c_srh, c_fos, c_thn, c_thb,
 *   x_dis, x_dev, x_sav, x_stl, x_srh, x_fos, x_thn, x_thb,
 *   HD, Exp*/
		10, 30, 30,  4, 20, 30, 45, 23,
		 0, 11, 10,  0,  3,  5, 20, 12,
		3, 45, //4, 30
                {
#if 0 /* mimicmage/mimicpriest/mimicmagepriest pure caster shaman as actually intended */
                        {
                                SKILL_COMBAT,
                                '+', 0,
                                '+', 300,//priests=750,istari=300
                        },
                        {
                                SKILL_MAGIC,
                                '+', 2000,
                                '+', 1000,
                        },
                        {
                                SKILL_CONVEYANCE,
                                '+', 1000,
                                '+', 1000,
                        },
                        {
                                SKILL_DEVICE,
                                '+', 0,
                                '+', 500,
                        },
                        {
                                SKILL_SPELL,
                                '+', 0,
                                '+', 500,
                        },
                        {
                                SKILL_MANA,
                                '+', 1000,
                                '+', 700,//600
                        },
                        {
                                SKILL_FIRE,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_AIR,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_EARTH,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_WATER,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_NATURE,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_DIVINATION,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_UDUN,
                                '+', 0,
                                '+', 900,
                        },
                        {
                                SKILL_META,
                                '+', 0,
                                '+', 500,
                        },
                        {
                                SKILL_MIND,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_HOFFENSE,
                                '+', 1000,
				'+', 900,
			},
			{
                                SKILL_HDEFENSE,
                                '+', 0,
				'+', 900,
                        },
                        {
                                SKILL_HCURING,
                                '+', 0,
				'+', 900,
                        },
                        {
                                SKILL_HSUPPORT,
                                '+', 0,
				'+', 900,
                        },
                        {
                                SKILL_MIMIC,
                                '+', 1000,
                                '+', 800,
				/* only: giant, dragon, animal, ghost, elemental, DR */
                        },
                        /* Sneakiness tree */
                        {
                                SKILL_SNEAKINESS,
                                '+', 0,
                                '+', 400,
                        },
                        {
                                SKILL_STEALTH,
                                '+', 1000,
                                '+', 600,
                        },

                        /* Necromancy tree */
                        {
                                SKILL_NECROMANCY,
                                '+', 0,
                                '+', 1500,
                        },
                        {
                                SKILL_TRAUMATURGY,
                                '+', 0,
                                '+', 1500,
                        },
                        {
                                SKILL_AURA_FEAR,
                                '+', 0,
                                '+', 1500,
                        },
                        {
                                SKILL_AURA_SHIVER,
                                '+', 0,
                                '+', 1500,
                        },
                        {
                                SKILL_AURA_DEATH,
                                '+', 0,
                                '+', 1500,
                        },
                        /* Health tree */
                        {
                                SKILL_HEALTH,
                                '+', 1000,
                                '+', 1000,
                        },
                        {
                                SKILL_DIG,
                                '+', 1000,
                                '+', 1000,
                        },
			/* Misc tree - let's keep it actually! */
                        {
                                SKILL_CALMNESS,
                                '+', 0,
                                '+', 900,
                        },
#else /* fighting shamans, rivalling priests/paladins/rangers - currently enabled \
	 since offensive spells are lacking, until spell system gets reworked */
                        {
                                SKILL_AXE,
                                '+', 0,
                                '+', 400,
                        },
                        {
                                SKILL_BLUNT,
                                '+', 0,
                                '+', 400,
                        },
			{
				SKILL_POLEARM,
				'+', 0,
				'+', 400,
			},
                        {
                                SKILL_MARTIAL_ARTS,
                                '+', 0,
                                '+', 400,
                        },
                        /* Combat tree */
                        {
                                SKILL_COMBAT,
                                '+', 0,
                                '+', 300,//priests=750,istari=300
                        },
                        {
                                SKILL_MASTERY,
                                '+', 0,
                                '+', 150,
                        },
                        /* Magic tree */
                        {
                                SKILL_MAGIC,
                                '+', 2000,
                                '+', 600,//500
                        },
                        {
                                SKILL_CONVEYANCE,
                                '+', 1000,
                                '+', 1000,
                        },
                        {
                                SKILL_DEVICE,
                                '+', 0,
                                '+', 500,
                        },
                        {
                                SKILL_SPELL,
                                '+', 0,
                                '+', 500,
                        },
                        {
                                SKILL_MANA,
                                '+', 1000,
                                '+', 700,//600
                        },
                        {
                                SKILL_FIRE,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_AIR,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_EARTH,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_WATER,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_NATURE,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_DIVINATION,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_UDUN,
                                '+', 0,
                                '+', 900,
                        },
                        {
                                SKILL_META,
                                '+', 0,
                                '+', 500,
                        },
                        {
                                SKILL_MIND,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_HOFFENSE,
                                '+', 1000,
				'+', 900,
//				'+', 1000,
			},
			{
                                SKILL_HDEFENSE,
                                '+', 0,
				'+', 900,
//				'+', 1000,
                        },
                        {
                                SKILL_HCURING,
                                '+', 0,
//				'+', 1100,
				'+', 900,
//				'+', 1000,
                        },
                        {
                                SKILL_HSUPPORT,
                                '+', 0,
				'+', 900,
//				'+', 1000,
                        },
                        {
                                SKILL_MIMIC,
                                '+', 1000,
                                '+', 800,
				/* only: giant, dragon, animal, ghost, elemental, DR */
                        },

                        /* Sneakiness tree */
                        {
                                SKILL_SNEAKINESS,
                                '+', 0,
                                '+', 400,
                        },
                        {
                                SKILL_STEALTH,
                                '+', 1000,
                                '+', 600,
                        },

                        /* Necromancy tree */
                        {
                                SKILL_NECROMANCY,
                                '+', 0,
                                '+', 1500,
                        },
                        {
                                SKILL_TRAUMATURGY,
                                '+', 0,
                                '+', 1500,
                        },
                        {
                                SKILL_AURA_FEAR,
                                '+', 0,
                                '+', 1500,
                        },
                        {
                                SKILL_AURA_SHIVER,
                                '+', 0,
                                '+', 1500,
                        },
                        {
                                SKILL_AURA_DEATH,
                                '+', 0,
                                '+', 1500,
                        },
                        /* Health tree */
                        {
                                SKILL_HEALTH,
                                '+', 1000,
                                '+', 1000,
                        },
                        {
                                SKILL_DIG,
                                '+', 1000,
                                '+', 1000,
                        },
			/* Misc tree - let's keep it actually! */
                        {
                                SKILL_CALMNESS,
                                '+', 0,
                                '+', 900,
                        },
                        {
                                SKILL_INTERCEPT,
                                '+', 0,
                                '+', 500,
                        },
#endif
                }
	},

	{
                "Runemaster",	/* A mage/rogue class, more caster than fighter, but with high spell damage / low durability.
				 * Intended to be the 'warrior' of the magic classes, but with allowed hybridization.
				 */
                TERM_L_BLUE, 
		{ 1, 2, -3, 3, -3, -3},
		{15, 0+100, 0, 19+100, 0, 0},
/*   c_dis, c_dev, c_sav, c_stl, c_srh, c_fos, c_thn, c_thb,
 *   x_dis, x_dev, x_sav, x_stl, x_srh, x_fos, x_thn, x_thb,
 *   HD, Exp*/
		30, 23, 20,  2, 20, 30, 45, 40,
		10, 11, 10,  0,  3,  5, 20, 20,
		 5, 20,
        {
			{
				SKILL_COMBAT,
				'+', 0,
				'+', 1000,
			},
			{
				SKILL_TECHNIQUE,
				'+', 1000,
				'+', 0,
			},
			/* "I am able to learn sword, but not weapon mastery in general, nor combat" */
			/* combat is ok, but i guess they aren't disciplined enough for w-mastery ;) */
			{
				SKILL_SWORD,
				'+', 0,
				'+', 900,
			},
			{
				SKILL_CRITS,
				'+', 0,
				'+', 400,
			},
			{
				SKILL_AXE,
				'+', 0,
				'+', 800,
			},
			{
				SKILL_BLUNT,
				'+', 0,
				'+', 800,
			}, 
			{
				SKILL_POLEARM,
				'+', 0,
				'+', 800,
			},
			/* MA ratio is so low, let's remove it and increase boomerangs, for class variety? */
			/* For flavour, make them boomerang specialists (enchantable), removing ammo-fueled types.  */
			/* This should further distance them from rangers as a class. */
			/*
			{
				SKILL_MARTIAL_ARTS,
				'+', 0,
				'+', 200,
			},
			*/
			{
				SKILL_BOOMERANG,
				'+', 0,
				'+', 1000,
			},
			/*
			{
				SKILL_SLING,
				'+', 0,
				'+', 700,
			},
			*/
			/* Starting MP equivalent to Istari, er, or just slightly worse! (caster/blaster) */
			{
				SKILL_MAGIC,
				'+', 3000, //4000
				'+', 1000,
			},
			/* Sneakiness tree */
			{
				SKILL_SNEAKINESS,
				'+', 1000,
				'+', 600,
			},
			{
				SKILL_STEALTH,
				'+', 1000,
				'+', 600,
			},
			/* Disabling trapping too, runies would use glyphs, and don't want additional inventory clutter. */
			/*
			{
				SKILL_TRAPPING,
				'+', 0,
				'+', 900,
			},
			*/
			{
				SKILL_STEALING,
				'+', 0,
				'+', 700,
			},
			{
				SKILL_BACKSTAB,
				'+', 0,
				'+', 700,
			},
			{
				SKILL_DODGE,
				'+', 0,
				'+', 700,
			},
			{
				SKILL_CALMNESS,
				'+', 0,
				'+', 1000,
			},
			{
				SKILL_INTERCEPT,
				'+', 0,
				'+', 1000,
			},
			{
				SKILL_R_LITE,
				'+', 0,
				'+', 1000,
			},
			{
				SKILL_R_DARK,
				'+', 0,
				'+', 1000,
			},
			{
				SKILL_R_NEXU,
				'+', 0,
				'+', 1000,
			},
			{
				SKILL_R_NETH,
				'+', 0,
				'+', 1000,
			},
			{
				SKILL_R_CHAO,
				'+', 0,
				'+', 1000,
			},
			{
				SKILL_R_MANA,
				'+', 0,
				'+', 1000,
			},
			/* Necromancy tree */
			{
				SKILL_NECROMANCY,
				'+', 0,
				'+', 1000,
			},
			{
				SKILL_TRAUMATURGY,
				'+', 0,
				'+', 1000,
			},
			{
				SKILL_AURA_FEAR,
				'+', 0,
				'+', 1000,
			},
			{
				SKILL_AURA_SHIVER,
				'+', 0,
				'+', 1000,
			},
			{
				SKILL_AURA_DEATH,
				'+', 0,
				'+', 1000,
			},
			/* Health tree */
			{
				SKILL_HEALTH,
				'+', 1000,
				'+', 1000,
			},
			{
				SKILL_SWIM,
				'+', 0,
				'%', 110,
			},
			{
				SKILL_DIG,
				'+', 1000,
				'+', 1600,
			}, 
		}
	},

#ifdef ENABLE_MCRAFT
	{
                "Mindcrafter", /* old mindcrafter idea reincarnated in slightly different design - C. Blue:
				  At first made them a 'caster with melee ability', but now changed mind ;) to
				  actually view them as 'fighters with psi abilities' instead, improving vitality. */
                TERM_SLATE,
//		{ -1, 3, 0, -1, -1, 1},
		{ 2, 2, 0, 0, 0, 1},
//		{21+100, 0+100, 0, 19+100, 0, 0}, 18/30;10 pretty unreachable with {0,2,0,0,0,1}
		{19+100, 0+100, 0, 10+100, 0, 0},
/*   c_dis, c_dev, c_sav, c_stl, c_srh, c_fos, c_thn, c_thb,
 *   x_dis, x_dev, x_sav, x_stl, x_srh, x_fos, x_thn, x_thb,
 *   HD, Exp*/
		30, 28, 36,  3, 35, 14, 55, 45,
		 0,  9,  5,  0,  3,  3, 26, 25,
//		5, 25,
		6, 25,
                {
                        /* Combat tree */
                        {
                                SKILL_COMBAT,
                                '+', 1000,
//                                '+', 800,
                                '+', 1000,
                        },
                        {
                                SKILL_MASTERY,
                                '+', 1000,
//                                '+', 400,
//                                '+', 600,
                                '+', 800,
                        },
                        {
                                SKILL_TECHNIQUE,
                                '+', 1000,
                                '+', 0,
                        },
                        {
                                SKILL_SWORD,
                                '+', 0,
//                                '+', 650,
                                '+', 750,
                        },
#if 1 /* gory and brutal axes distract their mind..well, or maybe not? */
                        {
                                SKILL_AXE,
                                '+', 0,
//                                '+', 600,
                                '+', 700,
                        },
#endif
                        {
                                SKILL_BLUNT,
                                '+', 0,
//                                '+', 650,
                                '+', 750,
                        },
			{
				SKILL_POLEARM,
				'+', 0,
//				'+', 650,
				'+', 750,
			},
                        {
                                SKILL_MARTIAL_ARTS,
                                '+', 0,
//                                '+', 600,
                                '+', 700,
                        },
		/*ranged weapon skills shouldnt be better than "Mimic" class. more like "Istar" which has none at all.*/
                        {
                                SKILL_SLING,
                                '+', 1000,
                                '+', 250,
                        },
                        {
                                SKILL_XBOW,
                                '+', 0,
                                '+', 300,
                        },
                        {
                                SKILL_BOOMERANG,
                                '+', 1000,
                                '+', 250,
                        },

                        /* Magic tree */
                        {
                                SKILL_MAGIC,
                                '+', 1000,
                                '+', 800,
                        },
                        {
                                SKILL_DEVICE,
                                '+', 0,
                                '+', 700,
                        },
                        {
                                SKILL_PPOWER,
                                '+', 0,
				'+', 1500,
			},
			{
                                SKILL_TCONTACT,
                                '+', 0,
                                '+', 1500,
                        },
                        {
                                SKILL_MINTRUSION,
                                '+', 1000,
                                '+', 1500,
                        },

                        /* Sneakiness tree */
                        {
                                SKILL_SNEAKINESS,
                                '+', 1000,
                                '+', 700,
                        },
                        {
                                SKILL_STEALTH,
                                '+', 1000,
                                '+', 700, /* high stealth- jedi hand wave? */
                        },
			{
				SKILL_DISARM,
				'+', 0,
				'+', 700,
			},
			{
				SKILL_DODGE,
				'+', 0,
				'+', 400,
			},
                        {
                                SKILL_CALMNESS,
                                '+', 0,
                                '+', 1500,
                        },
                        {
                                SKILL_INTERCEPT,
                                '+', 0,
                                '+', 500,
                        },

                        /* Necromancy tree - disturb the mindcrafter slightly maybe*/
                        {
                                SKILL_NECROMANCY,
                                '+', 0,
                                '+', 700,
                        },
                        {
                                SKILL_TRAUMATURGY,
                                '+', 0,
                                '+', 800,
                        },
                        {
                                SKILL_AURA_FEAR,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_AURA_SHIVER,
                                '+', 0,
                                '+', 1000,
                        },
                        {
                                SKILL_AURA_DEATH,
                                '+', 0,
                                '+', 900,
                        },
                        /* Health tree */
                        {
                                SKILL_HEALTH,
                                '+', 1000,
                                '+', 1000,
                        },
                        {
                                SKILL_DIG,
                                '+', 1000,
                                '+', 900,
                        },
                }
	}
#endif
};


/* Racial traits, introduced for Draconians - C. Blue */
player_trait trait_info[MAX_TRAIT] = {
	{ /* Note: This trait #0 must be allowed for EXACTLY the races that DON'T have any trait.
	     This can be used to 'disable' all traits for a specific race: Just add it here. */
		"N/A",
#ifdef ENABLE_DRACONIAN_TRAITS
		0xFFFFFF & ~RFC,
#else
		0xFFFFFF, /* disable for all */
#endif
	},{	"Blue lineage",	RFC,//ELEC			res->imm	+brand+aura
	},{	"White lineage", RFC,//COLD			res->imm	+aura
	},{	"Red lineage", RFC,//FIRE			res->imm
	},{	"Black lineage", RFC,//ACID			res->imm
	},{	"Green lineage", RFC,//POIS			res->imm
	},{	"Multi-hued lineage", RFC,//base(+pois?)	base/pois
	},{	"Bronze lineage", RFC,//conf+fa(+fire?)+refl	conf/fa/refl
	},{	"Silver lineage", RFC,//cold+fa,refl (pois)	cold/pois/refl
	},{	"Golden lineage", RFC,//sound+acid,refl(+fear?)	acid/sound/refl
	},{	"Law lineage", RFC,//shards+sound		shards/sound
	},{	"Chaos lineage", RFC,//chaos			chaos/disen
	},{	"Balance lineage", RFC,//disen			disen/sound
#if 0
	},{	"Power lineage", RFC,//mana/res_tele?NOPE/rare!	reflect/blind/fear
#else
	},{	"", 0,
#endif
	},{	"Enlightened", 0, /* note: directly assigned live; must be N/A on char creation time */
	},{	"Corrupted", 0, /* note: directly assigned live; must be N/A on char creation time */
	},{	"", 0,
	},{	"", 0,
	},{	"", 0,
	},{	"", 0,
	},{	"", 0,
	},{	"", 0,
	},{	"", 0,
	},{	"", 0,
	},{	"", 0,
	},{	"", 0,
	},{	"", 0,
	},{	"", 0,
	},{	"", 0,
	},{	"", 0,
	},{	"", 0,
	},{	"", 0,
	},
};


/*
 * Player Classes.
 *
 *   Title,
 *   color,
 *   {STR,INT,WIS,DEX,CON,CHR},
 *   {STR,INT,WIS,DEX,CON,CHR} recommended minimum values,
 *   c_dis, c_dev, c_sav, c_stl, c_srh, c_fos, c_thn, c_thb,
 *   x_dis, x_dev, x_sav, x_stl, x_srh, x_fos, x_thn, x_thb,
 *   HD, Exp
 */

/*
 * Note that this is the same for all classes (for now).
 *
 * Such a hack....
 */
magic_type ghost_spells[64] =
{
	{  1,   1, 0, 0},
	{ 10,   2, 0, 0},
	{ 15,   3, 0, 0},
	{ 20,   5, 0, 0},
	{ 25,  10, 0, 0},
	{ 35,  60, 0, 0},
	{ 45, 100, 0, 0},

	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0},
	{ 99,   0, 0, 0}
};


/*
 * Class titles for the player.
 *
 * The player gets a new title every five levels, so each class
 * needs only ten titles total.
 *
 * New: Fields x,2 and x,3 are for short titles sent to the client
 *      which must be 12 characters max in length  - C. Blue
 */
cptr player_title[MAX_CLASS][11][4] =
{
	/* Warrior */
	{
	        {"Rookie", "Rookie", "Rookie", "Rookie", },
		{"Mercenary", "Mercenary", "Mercenary", "Mercenary", },
		{"Soldier", "Soldier", "Soldier", "Soldier", },
		{"Veteran", "Veteran", "Veteran", "Veteran", },
		{"Captain", "Captain", "Captain", "Captain", },
		{"Champion", "Champion", "Champion", "Champion", },
	        {"Hero", "Heroine", "Hero", "Heroine", },//heh they are back :)
		{"General", "General", "General", "General", },
		{"Baron", "Baroness", "Baron", "Baroness", },
		{"Duke", "Duchess", "Duke", "Duchess", },
		{"Lord", "Lady", "Lord", "Lady", },
	},

	/* Istar */
	{
		{"Novice", "Novice", "Novice", "Novice", },
		{"Apprentice", "Apprentice", "Apprentice", "Apprentice", },
		{"Trickster", "Trickster", "Trickster", "Trickster", },
		{"Illusionist", "Illusionist", "Illusionist", "Illusionist", },
		{"Spellbinder", "Spellbinder", "Spellbinder", "Spellbinder", },
		{"Evoker", "Evokeress", "Evoker", "Evokeress", },
		{"Conjurer", "Conjuress", "Conjurer", "Conjuress", },
		{"Sorcerer", "Sorceress", "Sorcerer", "Sorceress", },
		{"Warlock", "Warlock", "Warlock", "Warlock", },
		{"Mage", "Mage", "Mage", "Mage", },
		{"Arch-Mage", "Arch-Mage", "Arch-Mage", "Arch-Mage", },
	},

	/* Priest */
	{
		{"Believer", "Believer", "Believer", "Believer", },
		{"Acolyte", "Acolyte", "Acolyte", "Acolyte", },
		{"Adept", "Adept", "Adept", "Adept", },
		{"Curate", "Curate", "Curate", "Curate", },
		{"Canon", "Canon", "Canon", "Canon", },
		{"Priest", "Priestess", "Priest", "Priestess", },
		{"Bishop", "Bishop", "Bishop", "Bishop", },
		{"Arch-Bishop", "Arch-Bishop", "Arch-Bishop", "Arch-Bishop", },
		{"Cardinal", "Cardinal", "Cardinal", "Cardinal", },
		{"High Priest", "High Priestess", "High Priest", "H.Priestess", },
//		{"Spiritual Guardian", "Spiritual Guardian", },
		{"Patriarch", "Matriarch", "Patriarch", "Matriarch", },
	},

	/* Rogues */
	{
		{"Vagabond", "Vagabond", "Vagabond", "Vagabond", },
		{"Cutpurse", "Cutpurse", "Cutpurse", "Cutpurse", },
		{"Robber", "Robber", "Robber", "Robber", },
		{"Burglar", "Burglar", "Burglar", "Burglar", },
		{"Filcher", "Filcher", "Filcher", "Filcher", },
		{"Sharper", "Sharpress", "Sharper", "Sharpress", },
		{"Thief", "Thief", "Thief", "Thief", },
		{"Master Thief", "Master Thief", "Master Thief", "Master Thief", },
		{"Infiltrator", "Infiltratess", "Infiltrator", "Infiltratess", },
		{"Grandmaster Thief", "Grandmaster Thief", "GM-Thief", "GM-Thief", },
		{"Assassin", "Assassin", "Assassin", "Assassin", },
        },

	/* Mimic */
	{
		{"Pretender", "Pretender", "Pretender", "Pretender", },
		{"Modifier", "Modifier", "Modifier", "Modifier", },
		{"Copier", "Copyress", "Copier", "Copyress", },
		{"Multiple (1st)", "Multiple (1st)", "Multiple I", "Multiple I", },
		{"Multiple (2nd)", "Multiple (2nd)", "Multiple II", "Multiple II", },
		{"Shapeshifter", "Shapeshiftress", "Shapeshifter", "Shapeshftr.", },
		{"Metamorph", "Metamorph", "Metamorph", "Metamorph", },
		{"Changer", "Changeress", "Changer", "Changeress", },
		{"Master Changer", "Master Changeress", "M-Changer", "M-Changeress", },
		{"Grandmaster Changer", "Grandmaster Changeress", "GM-Changer", "GM-Changress", },
		{"Ultimate Changer", "Ultimate Changeress", "U-Changer", "U-Changeress", },
	},

	/* Archer */
	{
		{"Rock Thrower", "Rock Thrower", "Rock Thrower", "Rock Thrower", },
		{"Slinger", "Slinger", "Slinger", "Slinger", },
		{"Great Slinger", "Great Slinger", "Great Slinger", "Gr.Slinger", },
		{"Bowsen", "Bowsen", "Bowsen", "Bowsen", },
		{"Bowman", "Bow Maiden", "Bowman", "Bow Maiden", },
		{"Great Bowman", "Great Bowmaiden", "Great Bowman", "Gr.Bowmaiden", },
		{"High Archer", "High Archer", "High Archer", "High Archer", },
		{"Grand Archer", "Grand Archer", "Grand Archer", "Grand Archer", },
		{"Veteran Archer", "Veteran Archer", "Vet. Archer", "Vet. Archer", },
		{"Master Archer", "Master Archer", "M-Archer", "M-Archer", },
		{"Grandmaster Archer", "Grandmistress Archer", "GM-Archer", "GM-Archer", },
	},

        /* Paladin */
	{
		{"Page", "Page", "Page", "Page", },
		{"Squire", "Squiress", "Squire", "Squiress", },
//		{"Acolyte", "Acolyte", "Acolyte", "Acolyte", },
		{"Faithful", "Faithful", "Faithful", "Faithful", },
		{"Zealot", "Zealot", "Zealot", "Zealot", },
		{"Defender", "Defender", "Defender", "Defender", },
		{"Crusader", "Crusader", "Crusader", "Crusader", },
		{"Knight", "Knight", "Knight", "Knight", },
		{"Blessed Knight", "Blessed Knight", "Bless.Knight", "Bless.Knight", },
		{"Sacred Knight", "Sacred Knight", "Sacr.Knight", "Sacr.Knight", },
		{"Paladin", "Paladin", "Paladin", "Paladin", },
	        {"Knight Commander", "Knight Commander", "Knight Cmdr.", "Knight Cmdr.", },
        },

        /* Ranger */
	{
		{"Rookie", "Rookie", "Rookie", "Rookie", },
		{"Path Finder", "Path Finder", "Path Finder", "Path Finder", },
		{"Deputy", "Deputy", "Deputy", "Deputy", },
		{"Guard", "Guard", "Guard", "Guard", },
		{"Scout","Scout", "Scout","Scout", },
		{"Sentry", "Sentry", "Sentry", "Sentry", },
		{"Overseer", "Overseer", "Overseer", "Overseer", },
		{"Guard Captain", "Guard Captain", "Guard Captain", "Guard Captain", },
		//removed 'Ranger' and added 'Ranger Champion'
		{"Supervisor", "Supervisor", "Supervisor", "Supervisor", },
//		{"Ranger", "Ranger", "Ranger", "Ranger", },
		{"High Ranger", "High Ranger", "High Ranger", "High Ranger", },
//	 	{"Ranger Champion", "Ranger Champion", },
        	{"Ranger Chieftain", "Ranger Chieftain", "Ranger Chief", "Ranger Chief", }, /* to check: Isn't it Chief Ranger rather? */
        },

	/* Adventurer */
	{
		{"Rambler", "Rambler", "Rambler", "Rambler", },
		{"Walker", "Walker", "Walker", "Walker", },
		{"Tripper", "Tripper", "Tripper", "Tripper", },
		{"Tourist", "Tourist", "Tourist", "Tourist", },
		{"Strider", "Strider", "Strider", "Strider", },
		{"Voyager", "Voyager", "Voyager", "Voyager", },
		{"Traveller", "Traveller", "Traveller", "Traveller", },
		{"Spelunker", "Spelunker", "Spelunker", "Spelunker"},
		{"Explorer", "Explorer", "Explorer", "Explorer", },
		{"Navigator", "Navigatress", "Navigator", "Navigatress", },
		{"Adventurer", "Adventuress", "Adventurer", "Adventuress", },
	},

	/* Druid */
	{
		{"Green", "Green", "Green", "Green", },
		{"Tree Hugger", "Tree Hugger", "Tree Hugger", "Tree Hugger", },
		{"Flower Boy", "Flower Girl", "Flower Boy", "Flower Girl", },
		{"Herbalist", "Herbalist", "Herbalist", "Herbalist", },
		{"Spiritualist","Spiritualist", "Spiritualist","Spiritualist", },
		{"Elder", "Elder", "Elder", "Elder", },
		{"Druid", "Druid", "Druid", "Druid", },
		{"High Druid", "High Druid", "High Druid", "High Druid", },
		{"Master Druid", "Master Druid", "Master Druid", "Master Druid", },
		{"Wildlife Preserver", "Wildlife Preserver", "Wl.Preserver", "Wl.Preserver", },
		{"Arch-Druid", "Arch-Druid", "Arch-Druid", "Arch-Druid", }, //was Arch Druid
	},

	/* Shaman */
	{
		{"Smoker", "Smoker", "Smoker", "Smoker", },
		{"Novice Walker", "Novice Walker", "Nov. Walker", "Nov. Walker", },
		{"Walker", "Walker", "Walker", "Walker", },
		{"Spiritwalker", "Spiritwalker", "Spiritwalker", "Spiritwalker", },
		{"Bone Fletcher", "Bone Fletcher", "Bone Fletchr", "Bone Fletchr", },
		{"Cursed", "Cursed", "Cursed", "Cursed", },
		{"Chanter", "Chantress", "Chanter", "Chantress", },
		{"Elder Chanter", "Elder Chantress", "Eld.Chanter", "El.Chantress", },
//		{"Spiritwatcher", "Spiritwatcher", },
		{"Shaman", "Shaman", "Shaman", "Shaman", },
		{"Elder Shaman", "Elder Shaman", "Elder Shaman", "Elder Shaman", },
		{"Shaman King", "Shaman Queen", "Shaman King", "Shaman Queen", },
	},
	/* Runemaster */
	{
		{"Digger", "Digger", "Digger", "Digger", },
		{"Rune Tracer", "Rune Tracer", "Rune Tracer", "Rune Tracer", },
		{"Rock Collector", "Rock Collector", "R.Collector", "R.Collector", },
//		{"Rock Painter", "Rock Paintress", "Rock Painter", "Rock Paintrs", },
		{"Fire Starter", "Fire Starter", "Fire Starter", "Fire Starter", },
		{"Treasure Hunter", "Treasure Hunter", "T.Hunter", "T.Hunter", },
//		{"Archaeologist", "Archaeologist", "Professor", "Professor," }, //too cool for 12 letters? ^^
		{"Archaeologist", "Archaeologist", "Archaelgst.", "Archaelgst.", },
		{"Earth Guard", "Earth Guard", "Earth Guard", "Earth Guard", },
		{"Rune Knight", "Rune Knight", "Rune Knight", "Rune Knight", },
		{"Rune Keeper", "Rune Keepress", "Rune Keeper", "Rune Keeprss", },
		{"Runemaster", "Runemistress", "Runemaster", "Runemistress", },
		{"Grand Runemaster", "Grand Runemistress", "G-Runemaster", "G-Runemstrss", },
        },
	/* Mindcrafter */
	{
//		{"Simple-minded", "Simple-minded", "Simple-mind", "Simple-mind", },
//		{"Reflector", "Reflectress", "Reflector", "Reflectress", },
//		{"Paranoid", "Paranoid", "Paranoid", "Paranoid", },
//		{"Aware", "Aware", "Aware", "Aware", },
		{"Wary", "Wary", "Wary", "Wary", },
		{"Fathomer", "Fathomer", "Fathomer", "Fathomer", },
		{"Thinker", "Thinker", "Thinker", "Thinker", },
		{"Biaser", "Biaser", "Biaser", "Biaser", },
		{"Convincer", "Convincer", "Convincer", "Convincer", },
		{"Warper", "Warper", "Warper", "Warper", },
		{"Psychic", "Psychic", "Psychic", "Psychic", },
		{"Telepath", "Telepath", "Telepath", "Telepath", },
		{"Manipulator", "Manipulatress", "Manipulator", "Manipulatrs.", },
		{"Controller", "Controller", "Controller", "Controller", },
		{"Master Mindcrafter", "Master Mindcraftress", "M-Mindcrftr.", "M-Mindcrftr.", },
	},
};

/*
 * Special Class titles for the player who is way > 50. (C. Blue)
 * 60 (usually no change I'd say =) wait, or maybe), 70, 80, 90, 99
 * It was time to add female titles too!
 */
cptr player_title_special[MAX_CLASS][5][4] =
{
	/* Warrior */
	{
#if 1
		{"Highlord", "Highlady", "Highlord", "Highlady", },
		{"Overlord", "Overlord", "Overlord", "Overlord", },
//  		{"Hero", "Hero", }, hero is back in the normal warrior ranks!
		{"Destroyer", "Destroyess", "Destroyer", "Destroyess", },
		{"Annihilator", "Annihilatress", "Annihilator", "Annihilatrss", },
		{"Titan", "Titan", "Titan", "Titan", },
#else
		{"Admiral", "Admiral", },
		{"Bombardier", "Bombardier", },
		{"Chief Marshal", "Chief Marshal", },
		{"Field Strategist", "Field Strategist", },
		{"Chief Admiral", "Chief Admiral", },
#endif
	},

	/* Istar */
	{
		{"Istar", "Istar", "Istar", "Istar", },
		{"Dragon Lord", "Dragon Lady", "Dragon Lord", "Dragon Lady", },/* explanation about all the 'Dragon..' stuff: I was out of ideas and
						    just thought of 'Earthsea Quartet' from Ursula LeGuin - C. Blue */
		{"Dragon Highlord", "Dragon Highlady", "Dragon HLord", "Dragon HLady", },//yolady
		{"Dragon Overlord", "Dragon Overlady", "Dragon OLord", "Dragon OLady", },//I need some improvements here....
		{"Dragon Arch-Mage", "Dragon Arch-Mage", "Drg.Archmage", "Drg.Archmage", },
	},

	/* Priest */
	{
		{"Old Patriarch", "Old Matriarch", "Old Patriar.", "Old Matriar.", },
		{"Saint", "Saint", "Saint", "Saint", },
		{"Ascended", "Ascended", "Ascended", "Ascended", },
		{"Demi", "Demi", "Demi", "Demi", }, //Pope? :)
		{"Holy Diver", "Holy Diver", "Holy Diver", "Holy Diver", }, //w00t!
	},

	/* Rogues */
	{
//		{"Grand Assassin", "Grand Assassin", },
//		{"Master Assassin", "Master Assassin", },
//commented out: first master, then hand = wrong order ^^	{"Death's Master", "Death's Mistress", "Dth.Master", "Dth.Mistress", },
		{"Phantom", "Phantom", "Phantom", "Phantom" },
//		{"Legendary Assassin", "Legendary Assassin", "Lgd.Assassin", "Lgd.Assassin", },
		{"Myth", "Myth", "Myth", "Myth", },
		{"Terror", "Terror", "Terror", "Terror" },
//		{"Mythical Assassin", "Mythical Assassin", "Myt.Assassin", "Myt.Assassin", },
		{"Death's Hand", "Death's Hand", "Death's Hand", "Death's Hand", },
		{"Death Fate", "Death Fate", "Death Fate", "Death Fate", },
/* yeah it's fitting, but let's not make the game JOKEBAND anyway */
//		{"RNG", "RNG", }, //LOL! Perfect, do you not think so? :) -adam 
	},

	/* Mimic */
	{
		{"Faker", "Fakeress", "Faker", "Fakeress", },
		{"Doppelganger", "Doppelganger", "Doppelganger", "Doppelganger", },
		{"Transformer", "Transformer", "Transformer", "Transformer", },
		{"Replicator", "Replicatress", "Replicator", "Replicatress", },
//		{"Master Replicator", "Master Replicatress", "M-Replicator", "M-Replicatrs", },
		{"Unlimited", "Unlimited", "Unlimited", "Unlimited", },
	},

	/* Archer */
	{
		{"Elite Archer", "Elite Archer", "Elite Archer", "Elite Archer", },
		{"Grand Elite Archer", "Grand Elite Archer", "GE-Archer", "GE-Archer", },
		{"Legendary Archer", "Legendary Archer", "Legd.Archer", "Legd.Archer", },
		{"Sirring Death", "Sirring Death", "Sirrg.Death", "Sirrg.Death", },
		{"Golden Eye", "Golden Eye", "Golden Eye", "Golden Eye", },
	},

	/* Paladin */
	{
	        {"Sacred Defender", "Sacred Defender", "Sac.Defender", "Sac.Defender", },
		{"Sacred Avenger", "Sacred Avenger", "Sacr.Avenger", "Sacr.Avenger", },
		{"Holy Avenger", "Holy Avenger", "Holy Avenger", "Holy Avenger", },
//		{"Holy Defender", "Holy Defender", }, defender comes before avenger if at all;
//							DF and HA are old 'good' ego mods from predecessors.
		{"Holy King", "Holy Queen", "Holy King", "Holy Queen", },
		{"God's Hand", "God's Hand", "God's Hand", "God's Hand", },
	},

	/* Ranger */
	{
		{"Elite Ranger", "Elite Ranger", "Elite Ranger", "Elite Ranger", },
//		{"Ranger Supervisor", "Ranger Supervisor", "Ranger Svis.", "Ranger Svis.", },
		{"Champion of Law", "Champion of Law", "Champ of Law", "Champ of Law", },
		{"Lord of Law", "Lady of Law", "Lord of Law", "Lady of Law", },
//		{"Ranger Commander", "Ranger Commander", "Ranger Cmdr.", "Ranger Cmdr.", },
		{"Legend", "Legend", "Legend", "Legend", },
		{"Justice", "Justice", "Justice", "Justice", },
	},

	/* Adventurer */
	{
		{"Seasoned Adventurer", "Seasoned Adventuress", "Seasoned Adv", "Seasoned Adv", },
		{"Famous Adventurer", "Famous Adventuress", "Famous Adv.", "Famous Adv.", },
		{"Grand Adventurer", "Grand Adventuress", "Grand Advntr", "Grand Advtrs", },
		{"Legendary Adventurer", "Legendary Adventuress", "Legend. Adv.", "Legend. Adv.", },
		{"Mythical Adventurer", "Mythical Adventuress", "Mythic Adv.", "Mythic Adv.", },
	},

	/* Druid */
	{
		{"Forest Guardian", "Forest Guardian", "Forest Guard", "Forest Guard", },
		{"Wind Evoker", "Wind Evokeress", "Wind Evoker", "Wind Evokrss", },
		{"Forest Keeper", "Forest Keepress", "Forest Kpr.", "Forest Kprs.", },
		{"Autumn", "Autumn", "Autumn", "Autumn", },
		{"Evergreen", "Evergreen", "Evergreen", "Evergreen", },
	},

	/* Shaman */
	{
		{"Spirit Keeper", "Spirit Keepress", "Sprt.Keeper", "Spt.Keepress", },
		{"Spirit Master", "Spirit Mistress", "Sprt.Master", "Spt.Mistress", },
		{"Realm Keeper", "Realm Keepress", "Realm Keeper", "Realm Kprss.", },
		{"Realm Master", "Realm Mistress", "Realm Master", "Realm Mistr.", },
		{"Presence", "Presence", "Presence", "Presence", },
	},

	/* Runemaster */
	{
//		{"Grand Runemaster", "Grand Runemistress", "G.Runemaster", "G.Runemstrss", },
		{"Force Master", "Force Mistress", "Force Master", "Force Mstrss", },
		//{"Elemental Overlord", "Elemental Overlady", "E-Overlord", "E-Overlady", },
		{"Elemental Channelist", "Elemental Channelist", "E-Channelist", "E-Channelist", },
		{"Elemental Master", "Elemental Master", "Elemental-M", "Elemental-M", },
		{"Elemental Vortex", "Elemental Vortex", "Elemn.Vortex", "Elemn.Vortex", },
		{"Savant", "Savant", "Savant", "Savant", },
	},

	/* Mindcrafter */
	{
		{"Master Manipulator", "Master Manipulatress", "M.Manipultr.", "M.Manipultr.", },
		{"Master Controller", "Master Controller", "M.Controllr.", "M.Controllr.", },
		{"Alterator", "Alteratress", "Alterator", "Alteratress", },
		{"Reality Shifter", "Reality Shifter", "Real.Shifter", "Real.Shifter", },
		{"Truth", "Truth", "Truth", "Truth", },
	},
};

/*
 * Certain "screens" always use the main screen, including News, Birth,
 * Dungeon, Tomb-stone, High-scores, Macros, Colors, Visuals, Options.
 *
 * Later, special flags may allow sub-windows to "steal" stuff from the
 * main window, including File dump (help), File dump (artifacts, uniques),
 * Character screen, Small scale map, Previous Messages, Store screen, etc.
 *
 * The "ctrl-i" (tab) command flips the "Display inven/equip" and "Display
 * equip/inven" flags for all windows.
 *
 * The "ctrl-g" command (or pseudo-command) should perhaps grab a snapshot
 * of the main screen into any interested windows.
 */


/* desc, min_lv, rchance, dd, ds, effect */
martial_arts ma_blows[MAX_MA] =
{
	{ "You punch %s",                          1, 0, 1, 4, 0 },
	{ "You kick %s",                           2, 0, 1, 6, 0 },
	{ "You strike %s",                         3, 0, 1, 7, 0 },
	{ "You ram %s with your knee",             5, 5, 2, 3, MA_KNEE },
	{ "You strike %s with your elbow",            7, 5, 1, 8, 0 },
	{ "You butt %s",                           9, 10, 2, 5, 0 },
	{ "You kick %s",                           11, 10, 2, 5, MA_SLOW },
	{ "You uppercut %s",                       13, 12, 4, 3, 4 },
	{ "You double-kick %s",                    16, 15, 4, 4, 0 },
	{ "You strike %s with a Cat's Claw",       20, 20, 6, 3, 0 },
	{ "You hit %s with a jump kick",           25, 25, 3, 9, 6 },
	{ "You strike %s with an Eagle's Claw",    29, 25, 7, 4, 0 },
	{ "You hit %s with a circle kick",         33, 30, 4, 9, 0 },
	{ "You punch %s with an Iron Fist",        37, 35, 6, 6, 8 },
	{ "You hit %s with a flying kick",         41, 35, 5, 8, 0 },
	{ "You punch %s with a Dragon Fist",       45, 35, 6, 8, 10 },
	{ "You hit %s with a Crushing Blow",       48, 35, 8, 7, 12 },
	/* Kings only (for NR:) */
	{ "You bash %s with a Titan's Fist",       48, 45, 8, 5, 20 },
	{ "You strike %s with a Phoenix Claw",     48, 45, 5, 9, MA_ROYAL_SLOW },
};

/*
 * Months
 */
int month_day[9] =
{
	0,      /* 1 day */

	1,      /* 54 days */
	55,     /* 72 days */
	127,    /* 54 days */

	181,    /* 3 days */

	184,    /* 54 days */
	238,    /* 72 days */
	310,    /* 54 days */

	364,    /* 1 day */
};
cptr month_name[9] =
{
	"Yestare",

	"Tuile",
	"Laire",
	"Yavie",

	"Enderi",

	"Quelle",
	"Hrive",
	"Coire",

	"Mettare",
};


/*
 * Quick hack for towns -- this should die	- Jir -
 */
/* FIXME: Dungeons don't match the Tolkien themes;
 * they're simply used to match the necessity 
 */
town_extra town_profile[6]=
{
	/* Vanilla */
	{
		"Town",
		FEAT_GRASS,
		FEAT_GRASS,
		90,
		WILD_GRASSLAND,
		{
			0,	/* No dungeon unless admin creates one */
			0,
		},

		1,
		127,
		FALSE,
		0L,
		0L,
	},

	/* Bree */
	{
		"Bree",
		FEAT_TREE,
		FEAT_GRASS,
		98,
		WILD_FOREST,
		{
			4,	/* Barrow-Downs */
			30,	/* Training Tower */
		},

		1,
		60,
		FALSE,
		0L,
		0L,
	},

	/* Gondolin */
	{
		"Gondolin",
		FEAT_GRASS,
		FEAT_DIRT,
		70,
		WILD_GRASSLAND,
		{
			2,	/* Mordor */
			0,
		},

		20,
		80,
		FALSE,
		0L,
		0L,
	},

	/* Minas Anor */
	{
		"Minas Anor",
		FEAT_MOUNTAIN,
		FEAT_SAND,
		90,
		WILD_MOUNTAIN,
		{
			16,	/* Paths of the Dead */
			0,
		},

		40,
		80,
		TRUE,
		0L,
		0L,
	},

	/* Lothlorien */
	{
		"Lothlorien",
		FEAT_DEEP_WATER,
		FEAT_SHAL_WATER,
		80,
		WILD_RIVER,
		{
			3,	/* Angband */
			0,
		},

		60,
		80,
		FALSE,
		0L,
		0L,
	},

	/* Khazad-dum */
	{
		"Khazad-dum",
		FEAT_MOUNTAIN,
		FEAT_ASH,
		70,
		WILD_MOUNTAIN,
		{
			3,	/* Angband (lazy :) */
			0,
		},

		80,
		120,
		TRUE,
		0L,
		0L,
	}
};


/* for C_BLUE_AI - meaning is: minimum AC of a player to make him appear pretty tough to monsters */
int p_tough_ac[51] = {
	5,6,7,8,9,		10,11,12,13,14,
	15,15,16,16,17,		17,18,18,19,19,
	20,22,24,26,28,		31,34,37,40,45,
	50,55,60,65,75,		85,95,105,115,
	120,123,126,128,130,	132,134,136,138,140,
	160	/* 51+, ie 'post king' */
};

